@@ -43,7 +43,6 @@ from ..workflows.config import create as create_config
 from ..workflows.transfer import transfer as workflows_transfer
 from ..workflows.decrypt import decrypt as workflows_decrypt
 from ..workflows.encrypt import encrypt as workflows_encrypt
-from ..workflows.request_sigs import verify_keylengths_and_request_sigs
 from ..workflows.upload_keys import verify_keylengths_and_upload_keys
 from ..protocols import (
     sftp,
@@ -121,17 +120,10 @@ def encrypt(
     dry_run: bool,
     passphrase_cmd: Optional[str],
     dtr_id: Optional[int] = None,
-    verify_dtr: Optional[bool] = None,
     **kwargs: Any,
 ) -> Optional[str]:
     """Wrapper for the main function of the encrypt workflow."""
 
-    if verify_dtr is None:
-        verify_dtr = not config.offline and dtr_id is not None
-    if config.offline and verify_dtr:
-        raise UserError(
-            "--verify_dtr is not possible when offline is enabled in the config."
-        )
     if config.sign_encrypted_data and not dry_run:
         kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
             "Please enter your gpg private key password:", passphrase_cmd
@@ -142,7 +134,6 @@ def encrypt(
         return workflows_encrypt(
             *files,
             dtr_id=dtr_id,
-            verify_dtr=verify_dtr,
             config=config,
             dry_run=dry_run,
             **kwargs,
@@ -174,8 +165,6 @@ def transfer(
     protocol: Optional[Type[Union[sftp.Protocol, liquid_files.Protocol]]] = None,
     protocol_args: Optional[Dict[str, Any]] = None,
     dry_run: bool = False,
-    verify_dtr: Optional[bool] = None,
-    force: bool = False,
     progress: Optional[ProgressInterface] = None,
 ) -> None:
     if connection is not None:
@@ -211,8 +200,6 @@ def transfer(
         protocol=protocol_instance,
         config=config,
         dry_run=dry_run,
-        verify_dtr=verify_dtr,
-        verify_pkg_name=False if force else config.verify_package_name,
         pkg_name_suffix=config.package_name_suffix,
         progress=progress,
         two_factor_callback=two_factor_callback,
@@ -224,7 +211,7 @@ def load_config_and_check_app_is_up_to_date() -> Config:
     local instance of the application is up-to-date.
     """
     cfg = load_config()
-    if not cfg.offline and cfg.check_version:
+    if cfg.check_version:
         check_version(cfg.repo_url)
     return cfg
 
@@ -243,13 +230,6 @@ class Cli(CliWithSubcommands):
     dry_run_override = dict(
         help="Perform checks on the input data, without running the actual command."
     )
-    verify_dtr_override = dict(
-        help="Verify DTR ID against an online database (portal). By default, "
-        "this check is performed if a DTR ID is provided or present in the "
-        "data package's metadata file, and skipped otherwise. Passing this "
-        "flag (or its disabling counterpart) will force (or disable) DTR ID "
-        "verification."
-    )
     subcommands = (
         Subcommand(
             decorate(
@@ -270,9 +250,10 @@ class Cli(CliWithSubcommands):
                     alias="-r",
                 ),
                 "dtr_id": dict(
-                    help="Data Transfer Request (DTR) ID (optional).", alias="-t"
+                    help="Data Transfer Request (DTR) ID (optional if "
+                    "`verify_dtr` is disabled in settings).",
+                    alias="-t",
                 ),
-                "verify_dtr": verify_dtr_override,
                 "purpose": dict(
                     help="Purpose of the DTR (PRODUCTION, TEST). "
                     "Mandatory only if `transfer_id` is specified."
@@ -281,11 +262,11 @@ class Cli(CliWithSubcommands):
                     help="Ignore errors about missing disk space", alias="-f"
                 ),
                 "output": dict(
-                    help="Output path (file or directory) to the "
-                    "encrypted package. If no path is specified, "
+                    help="Output path (directory path and/or file name) of "
+                    "the encrypted package. If no directory path is specified, "
                     "the output package is saved in the current working "
-                    "directory. If this argument is missing or path is a "
-                    "directory the file name is generated based on the "
+                    "directory. If this argument is missing or the path is a "
+                    "directory, the file name is generated based on the "
                     "current date and an optional suffix.",
                     default=None,
                     alias="-o",
@@ -328,13 +309,7 @@ class Cli(CliWithSubcommands):
                     "protocol_args option"
                 ),
                 "passphrase_cmd": dict(help=passphrase_override["help"]),
-                "force": dict(
-                    help="Ignore errors about package names not following the"
-                    "package name convention.",
-                    alias="-f",
-                ),
                 "dry_run": dry_run_override,
-                "verify_dtr": verify_dtr_override,
             },
         ),
         Subcommand(
@@ -362,13 +337,9 @@ class Cli(CliWithSubcommands):
             create_config,
             help="Commands related to config file",
         ),
-        Subcommand(
-            decorate(verify_keylengths_and_request_sigs, partial(config=config)),
-            overrides={"key_ids": dict(help="Key ids to request signatures for")},
-        ),
         Subcommand(
             decorate(verify_keylengths_and_upload_keys, partial(config=config)),
-            overrides={"key_ids": dict(help="Key ids to upload")},
+            overrides={"fingerprints": dict(help="Fingerprints to upload")},
         ),
     )
 
