@@ -132,7 +132,7 @@ class Argument:
 
 
 class ArgumentMutExGroup:
-    """Group of mutually exclusing arguments that can be added to a CLI parser."""
+    """Group of mutually exclusive arguments that can be added to a CLI parser."""
 
     def __init__(self, *args: Argument):
         self.args = args
@@ -284,13 +284,16 @@ class CliWithSubcommands:
             parser.add_argument("--version", action="version", version=self.version)
 
         # Add subcommands to the command line.
-        subparser_factory = parser.add_subparsers(
-            dest="action", help="Action help", required=self.required
+        subparser_factory = cast(
+            SubcommandParserBuilder,
+            parser.add_subparsers(
+                dest="action", help="Action help", required=self.required
+            ),
         )
         for cmd in self.subcommands:
             cmd.add_to_parser(parser_factory=subparser_factory, actions=actions)
 
-        # Retrive command line arguments passed by the user.
+        # Retrieve command line arguments passed by the user.
         cmd_args = vars(parser.parse_args(*args, **kwargs))
 
         # Run the function corresponding to the subcommand passed by the user.
@@ -318,7 +321,7 @@ def arguments_by_signature(
     omit_keywords: FrozenSet[str] = frozenset(),
     omit_positionals: FrozenSet[int] = frozenset(),
 ) -> Generator[Union[Argument, ArgumentMutExGroup], None, None]:
-    """Builds argparser arguments according to the signature of a function f.
+    """Build argparser arguments according to the signature of a function f.
     Type hint annotations are used to infer the type for argparse.
     """
     sig = inspect.signature(f)
@@ -328,8 +331,9 @@ def arguments_by_signature(
     unknown_parameters = set(overrides) - set(sig.parameters)
     if unknown_parameters:
         raise ValueError(
-            f"Function {f.__name__} does not have arguments {', '.join(unknown_parameters)} "
-            f"(which have been provided as parameter docs)"
+            f"Function {f.__name__} does not have arguments "
+            f"{', '.join(unknown_parameters)} "
+            "(which have been provided as parameter docs)"
         )
     has_keyword_only = any(
         p.kind is inspect.Parameter.KEYWORD_ONLY for p in sig.parameters.values()
@@ -376,7 +380,7 @@ def arguments_by_signature(
 def make_arg_names(
     name: str, aliases: Iterable[str], positional: bool
 ) -> Tuple[str, ...]:
-    """Combines name and aliases into one tuple of argument names
+    """Combine name and aliases into one tuple of argument names
     including "--".
     """
     n_dashes = min(2, len(name))
@@ -392,7 +396,7 @@ def make_arg_names(
 
 
 def parse_bool(s: str) -> bool:
-    """Returns True is the evaluated string is considered to represent the
+    """Return True is the evaluated string is considered to represent the
     value True, and False if not.
     """
     bool_true_literals = ("1", "true", "y", "yes")
