@@ -16,13 +16,12 @@ except ImportError:
 from libbiomedit.archive import archive_reader
 
 from .error import UserError
+from .metadata import METADATA_FILE, METADATA_FILE_SIG
 from .filesystem import delete_files
 from ..utils.progress import ProgressInterface, with_progress
 
 tarfile.DEFAULT_FORMAT = tarfile.PAX_FORMAT
 
-METADATA_FILE = "metadata.json"
-METADATA_FILE_SIG = "metadata.json.sig"
 CHECKSUM_FILE = "checksum.sha256"
 DATA_ARCHIVE = "data.tar.gz"
 DATA_FILE_ENCRYPTED = DATA_ARCHIVE + ".gpg"
