@@ -26,7 +26,7 @@ def compute_checksum_sha256(file_object: IO[bytes], block_size: int = 65536) ->
 
 def compute_checksum_on_write(
     stream: IO[bytes],
-    fout: io.FileIO,
+    output_file: io.FileIO,
     checksum_buffer: io.StringIO,
     block_size: int = 65536,
 ) -> None:
@@ -34,7 +34,7 @@ def compute_checksum_on_write(
     same time.
 
     :param stream: a stream of bytes to checksum and write to disk.
-    :param fout: output file object.
+    :param output_file: output file object.
     :param checksum_buffer: a buffer to store the checksum.
     :param block_size: size of blocks (in bytes) to be returned by the
         generator function. The default block size is 2^16 = 65536 bytes.
@@ -43,7 +43,7 @@ def compute_checksum_on_write(
     block = stream.read(block_size)
     while block:
         hash_value.update(block)
-        fout.write(block)
+        output_file.write(block)
         block = stream.read(block_size)
     checksum_buffer.write(hash_value.hexdigest())
     checksum_buffer.seek(0)
@@ -106,7 +106,7 @@ def generate_checksums_file_content(
 def verify_checksum(entry: Tuple[str, str]) -> Optional[str]:
     """Check whether the checksum of a given file matches the specified checksum.
 
-    :param entry: tuple of (checksum value, file to verify path)
+    :param entry: tuple of (checksum value, file to verify path).
     :return: None if the checksums match, or the file's actual checksum if
         it does not match the specified checksum.
     """
