@@ -20,11 +20,11 @@ from typing import (
 
 from libbiomedit import crypt
 
-from ..utils.config import Config
 from . import gpg
 from .error import UserError
 from .request import urlopen
 from .secret import Secret, reveal
+from ..utils.config import Config
 
 GPGStore = gpg.GPGStore
 ExceptionType = Union[Type[BaseException], Tuple[Type[BaseException], ...]]
@@ -35,7 +35,7 @@ R = TypeVar("R")
 def to_user_error(
     error_types: ExceptionType,
 ) -> Callable[[Callable[..., R]], Callable[..., R]]:
-    """A decorator to turn errors of type :error_types: into UserError"""
+    """A decorator to turn errors of type :error_types: into UserError."""
 
     def _to_user_error(f: Callable[..., R]) -> Callable[..., R]:
         @wraps(f)
@@ -50,49 +50,52 @@ def to_user_error(
     return _to_user_error
 
 
-def to_user_error_gen(
-    error_types: ExceptionType,
-) -> Callable[[Callable[..., Iterable[R]]], Callable[..., Iterable[R]]]:
-    """A decorator to turn errors of type :error_types: into UserError"""
-
-    def _to_user_error(f: Callable[..., Iterable[R]]) -> Callable[..., Iterable[R]]:
-        @wraps(f)
-        def wrapped(*args: Any, **kwargs: Any) -> Iterable[R]:
-            try:
-                yield from f(*args, **kwargs)
-            except error_types as e:
-                raise UserError(format(e)) from e
-
-        return wrapped
-
-    return _to_user_error
-
-
-validate_pub_key = to_user_error(RuntimeError)(crypt.validate_pub_key)
-retrieve_refresh_and_validate_keys = to_user_error_gen((RuntimeError, gpg.GPGError))(
-    partial(crypt.retrieve_refresh_and_validate_keys, url_opener=urlopen)
-)
-fingerprint2keyid = to_user_error(RuntimeError)(crypt.fingerprint2keyid)
 verify_metadata_signature = to_user_error(RuntimeError)(
     partial(crypt.verify_metadata_signature, url_opener=urlopen)
 )
 
 
-@to_user_error((gpg.GPGError, gpg.KeyserverError))
-def search_keyserver(search_term: str, keyserver: str) -> List[gpg.KeyInfo]:
-    """Search keyserver for keys matching the query"""
-    return list(gpg.search_keyserver(search_term, keyserver, url_opener=urlopen))
+@to_user_error((RuntimeError, gpg.GPGError))
+def retrieve_refresh_and_validate_keys(
+    key_identifiers: Iterable[str], config: Config
+) -> Tuple[gpg.Key, ...]:
+    """Performs the following tasks on the keys matching the specified
+    `key_identifiers`:
+     * Retrieve and/or refresh the keys from the keyserver specified in the
+       applications config file.
+     * Verifies that the keys are approved by the key validation authority.
+       This check is skipped if `config.verify_key_approval` is `False`.
+    """
+
+    # Retrieve and/or refresh keys from the keyserver.
+    keys = tuple(
+        crypt.retrieve_and_refresh_keys(
+            key_identifiers=key_identifiers,
+            gpg_store=config.gpg_store,
+            keyserver_url=config.keyserver_url,
+            allow_key_download=config.allow_gpg_key_autodownload,
+            url_opener=urlopen,
+        )
+    )
+
+    # Verify that all keys are approved by the central authority (via a call
+    # to portal).
+    if config.verify_key_approval:
+        config.portal_api.verify_key_approval(
+            fingerprints=(key.fingerprint for key in keys)
+        )
+    return keys
 
 
 @to_user_error(gpg.GPGError)
 def import_keys(key_data: str, gpg_store: GPGStore) -> None:
-    """Import keys from text"""
+    """Import keys from text."""
     return gpg_store.import_file(key_data.encode())
 
 
 @to_user_error(gpg.GPGError)
 def delete_pub_keys(fingerprints: List[str], gpg_store: GPGStore) -> None:
-    """Delete public key"""
+    """Delete public key."""
     return gpg_store.delete_pub_keys(*fingerprints)
 
 
@@ -100,12 +103,12 @@ def delete_pub_keys(fingerprints: List[str], gpg_store: GPGStore) -> None:
 def create_revocation_certificate(
     fingerprint: str, passphrase: str, gpg_store: GPGStore
 ) -> bytes:
-    """Create a revocation certificate for the key"""
+    """Create a revocation certificate for the key."""
     return gpg_store.gen_revoke(fingerprint, passphrase=passphrase)
 
 
 class KeyAlgorithm(enum.Enum):
-    """Encryption algorithm used in a public PGP key.
+    """Encryption algorithm used in public PGP keys.
     The numeric values associated to algorithms follow the GnuPG settings.
     """
 
@@ -115,43 +118,67 @@ class KeyAlgorithm(enum.Enum):
 
 
 def verify_key_length(key: gpg.Key, min_key_length: int = 4096) -> None:
+    """Verify that the type (algorithm) of a PGP keys is strong enough."""
+
+    allowed_key_description = (
+        f"Only RSA (min. key length: {min_key_length}) and ECC keys are allowed"
+    )
+
     try:
         algorithm = KeyAlgorithm(key.pub_key_algorithm)
-    except ValueError as exc:
+    except ValueError as e:
         if key.key_length < min_key_length:
             raise UserError(
-                f"Not allowed: key {key.key_id} is using an algorithm which we do not allow. "
-                f"Use either the RSA algorithm (min. key length: {min_key_length}) "
-                "or the ECC algorithm instead."
-            ) from exc
+                f"Non-allowed PGP key algorithm: key {key.key_id} is using a "
+                f"non-allowed algorithm. {allowed_key_description}."
+            ) from e
+
     if algorithm == KeyAlgorithm.ECC:
-        msg = (
-            f"Please be aware: key {key.key_id} is of type ECC, which is not supported "
-            "by older versions of GnuPG, available on older operating systems."
+        warnings.warn(
+            f"Please note: key {key.key_id} is of type ECC, which is not "
+            "supported by older versions of GnuPG."
         )
-        warnings.warn(msg)
         return
     if algorithm == KeyAlgorithm.DSA:
         raise UserError(
-            f"Not allowed: key {key.key_id} is of type DSA, which we do not allow."
+            f"Non-allowed PGP key algorithm: key {key.key_id} is of type DSA. "
+            f"{allowed_key_description}."
         )
     if key.key_length < min_key_length:
         raise UserError(
-            f"Not allowed: key {key.key_id} is shorter than the minimal "
-            f"required length of {min_key_length} bit"
+            f"Non-allowed PGP key algorithm: key {key.key_id} is shorter than "
+            f"the minimal required length. {allowed_key_description}."
         )
 
 
-@to_user_error(gpg.KeyserverError)
-def upload_keys(fingerprints: List[str], keyserver: str, gpg_store: GPGStore) -> None:
-    """Upload public key to keyserver"""
-    gpg_store.send_keys(*fingerprints, keyserver=keyserver, url_opener=urlopen)
+@to_user_error((gpg.KeyserverError, gpg.KeyserverOtherError))
+def request_key_verification(
+    token: str, address: str, keyserver: str
+) -> gpg.keyserver.VksUploadResponse:
+    """Triggers a verification email from the keyserver for given token."""
+    return gpg.keyserver.vks_request_verify(token, [address], keyserver)
 
 
-@to_user_error((gpg.KeyserverError, gpg.KeyserverKeyNotFoundError))
-def download_keys(fingerprints: List[str], keyserver: str, gpg_store: GPGStore) -> None:
-    """Download public key to keyserver"""
-    gpg_store.recv_keys(*fingerprints, keyserver=keyserver, url_opener=urlopen)
+@to_user_error((gpg.KeyserverError, gpg.KeyserverOtherError))
+def upload_keys(
+    fingerprints: List[str], keyserver: str, gpg_store: GPGStore
+) -> Tuple[gpg.keyserver.VksUploadResponse, ...]:
+    """Upload public keys to keyserver."""
+    return tuple(
+        gpg_store.vks_send_key(fingerprint, keyserver=keyserver)
+        for fingerprint in fingerprints
+    )
+
+
+@to_user_error(
+    (gpg.KeyserverError, gpg.KeyserverOtherError, gpg.KeyserverKeyNotFoundError)
+)
+def download_keys(
+    key_identifiers: List[str], keyserver: str, gpg_store: GPGStore
+) -> None:
+    """Download public keys from a verifying keyserver (VKS)."""
+    for key_identifier in key_identifiers:
+        gpg_store.vks_recv_key(key_identifier, keyserver=keyserver)
 
 
 def detach_sign_file(
@@ -160,7 +187,7 @@ def detach_sign_file(
     passphrase: Secret[str],
     gpg_store: GPGStore,
 ) -> bytes:
-    """Sign a file with a detached signature"""
+    """Sign a file with a detached signature."""
     try:
         with gpg_store.detach_sig(
             src, passphrase.reveal(), signature_fingerprint
@@ -171,7 +198,7 @@ def detach_sign_file(
 
 
 def enforce_passphrase(passphrase: Optional[Secret[str]]) -> Secret[str]:
-    """Verify that a passphrase is not empty, and return it"""
+    """Verify that a passphrase is not empty, and return it."""
     if passphrase is None:
         raise ValueError("No password given")
     return passphrase
@@ -183,7 +210,7 @@ def check_password(
     """Verify that the provided password matches the specified PGP key.
 
     The verification is done by trying to use the key specified via its
-    fingerprint to sign some mock data. If this opperation fails, the password
+    fingerprint to sign some mock data. If this operation fails, the password
     is incorrect and an error is raised.
     """
     try:
@@ -229,17 +256,30 @@ class KeyType(enum.Enum):
     secret = enum.auto()
 
 
+class UnpackError(UserError):
+    """Error class that displays an error message for the cases when a search
+    for a public/secret key on the user's local keyring does not yield exactly
+    one match.
+    """
+
+    def __init__(self, keys: Sequence[gpg.Key], key_type: KeyType, search_value: str):
+        if not keys:
+            msg_start = f"No {key_type.name} key"
+        else:
+            msg_start = f"Multiple {key_type.name} keys"
+        super().__init__(msg_start + f" matching: {search_value}")
+
+
 def search_pub_key(search_term: str, gpg_store: GPGStore, sigs: bool = True) -> gpg.Key:
-    """Search for a single public key in the local keyring based on the input
-    search term. If no or more than one key is matching the search term, an
-    error is raised.
+    """Search for exactly one public key in the user's local keyring.
 
     :param gpg_store: key database as gnupg object.
     :param search_term: search term for the key, e.g. fingerprint or key owner
         email address.
     :param sigs: if True, return key with signatures.
     :return: PGP key matching the search term.
-    :raises UnpackError:
+    :raises UnpackError: if either no or more than one key is matching the
+        search term.
     """
     keys = gpg_store.list_pub_keys(search_terms=(search_term,), sigs=sigs)
     try:
@@ -253,7 +293,7 @@ def search_pub_key(search_term: str, gpg_store: GPGStore, sigs: bool = True) ->
 
 def search_priv_key(search_term: str, gpg_store: GPGStore) -> gpg.Key:
     """Searches the user's local keyring for a secret key matching the search
-    term. Raises an error if no or more than one key are found.
+    term. Raises an error if either no or more than one key are found.
     """
     keys = gpg_store.list_sec_keys(search_terms=(search_term,))
     try:
@@ -265,19 +305,6 @@ def search_priv_key(search_term: str, gpg_store: GPGStore) -> gpg.Key:
     return key
 
 
-class UnpackError(UserError):
-    """Error class that displays an error message for the cases when a search
-    for a public/secret key on the user's local keyring does not yield exactly
-    one match"""
-
-    def __init__(self, keys: Sequence[gpg.Key], key_type: KeyType, search_value: str):
-        if not keys:
-            msg_start = f"No {key_type.name} key"
-        else:
-            msg_start = f"Multiple {key_type.name} keys"
-        super().__init__(msg_start + f" matching: {search_value}")
-
-
 def encrypt_and_sign(
     source: gpg.cmd.ISource,
     output: gpg.cmd.OSource,
@@ -291,7 +318,7 @@ def encrypt_and_sign(
 
     In this function, the compression level of the "encrypt()" method is set
     to 0 as we are only encrypting data that has already been compressed, or
-    has explicitely been requested by the user not to be compressed.
+    has explicitly been requested by the user not to be compressed.
 
     There is no check of the validity of the sender and recipient keys, as it
     is assumed that this is already done earlier.
@@ -354,39 +381,39 @@ def decrypt(
 ) -> List[str]:
     """Decrypt data.
 
-    :param source: data to encrypt.
-    :param output: encrypted data.
+    :param source: data to decrypt.
+    :param output: file where the decrypted data should be written to.
     :param gpg_store: directory containing GnuPG keyrings as gnupg object.
     :param passphrase: password associated to 'signature_fingerprint'. This
         parameter value can be set to None if the encrypted file should not be
         signed.
     :return: fingerprint or keyid of the signee's key.
-    :raises UserError:
+    :raises UserError: if the data could not be decrypted.
     """
     try:
         if isinstance(output, str):
-            with open(output, "wb") as fout:
-                sender_fprs = gpg_store.decrypt(
+            with open(output, "wb") as output_file:
+                sender_fingerprints = gpg_store.decrypt(
                     source=source,
-                    output=cast(io.FileIO, fout),
+                    output=cast(io.FileIO, output_file),
                     passphrase=reveal(passphrase),
                 )
         else:
-            sender_fprs = gpg_store.decrypt(
+            sender_fingerprints = gpg_store.decrypt(
                 source=source, output=output, passphrase=reveal(passphrase)
             )
     except gpg.GPGError as e:
         raise UserError(
             "Failed to decrypt. Error message from gpg:\n" + format(e)
         ) from e
-    if not sender_fprs:
+    if not sender_fingerprints:
         warnings.warn("Encrypted package is not signed by the sender")
-    elif len(sender_fprs) > 1:
+    elif len(sender_fingerprints) > 1:
         warnings.warn(
             "Encrypted package has multiple signatures. "
             "This is not compliant with the BiomedIT Protocol"
         )
-    return sender_fprs
+    return sender_fingerprints
 
 
 def create_key(
@@ -397,7 +424,8 @@ def create_key(
     key_type: str = "RSA",
     key_length: int = 4096,
 ) -> gpg.Key:
-    """Create a new PGP public/private key"""
+    """Create a new PGP public/private key."""
+
     min_pwd_len = 10
     if len(full_name) < 5:
         raise UserError("Full name must be at least 5 characters long.")
@@ -418,36 +446,3 @@ def create_key(
     if len(pkey) > 1:
         raise UserError(f"Multiple private keys found for: {fingerprint}")
     return pkey[0]
-
-
-def load_authority_key(sett_config: Config) -> Optional[gpg.Key]:
-    """Load (download if needed) and refresh the key authority's PGP key
-
-    The function returns None if either:
-     * No key authority fingerprint is given in the config.
-     * The key matching the fingerprint could not be retrieved, neither from
-       the local keyring nor from the keyserver.
-    """
-    if sett_config.key_authority_fingerprint:
-        try:
-            return crypt.retrieve_and_refresh_certification_authority_key(
-                key_fingerprint=sett_config.key_authority_fingerprint,
-                gpg_store=sett_config.gpg_store,
-                keyserver_url=sett_config.keyserver_url,
-                validate_key_origin=False,
-                allow_key_download=sett_config.allow_gpg_key_autodownload,
-                url_opener=urlopen,
-            )
-        except RuntimeError as e:
-            warnings.warn(
-                "The key validation authority's PGP key "
-                f"[{sett_config.key_authority_fingerprint}] could not be "
-                "found in your local keyring, nor could it be downloaded.\n"
-                "Please verify that the key validation authority fingerprint "
-                "and the keyserver URL settings are correct. Also verify that "
-                "you are not in offline mode and that PGP key auto-download "
-                "is enabled.\n"
-                f"Reason for failure: {e}"
-            )
-
-    return None
