@@ -1,13 +1,15 @@
 from typing import Dict, Any
 
 from libbiomedit import metadata as _metadata
-from libbiomedit.dpkg import METADATA_FILE as _METADATA_FILE
+from libbiomedit.metadata import METADATA_FILE as _METADATA_FILE
+from libbiomedit.metadata import METADATA_FILE_SIG as _METADATA_FILE_SIG
 
 from .error import UserError
 
 # Reexports
 alnum_str = _metadata.alnum_str
 METADATA_FILE = _METADATA_FILE
+METADATA_FILE_SIG = _METADATA_FILE_SIG
 Purpose = _metadata.Purpose
 HexStr1024 = _metadata.HexStr1024
 HexStr256 = _metadata.HexStr256
