@@ -11,12 +11,12 @@ from typing import (
     cast,
     TypeVar,
     Type,
+    Iterable,
 )
 
-from .theme import Action, IconRepainterWidget, PushButton
-from .model import AppData
 from .parallel import run_thread
 from .pyside import QtCore, QtWidgets, open_window
+from .theme import Action, IconRepainterWidget, PushButton
 from .. import APP_NAME_SHORT
 from ..core.secret import Secret
 from ..utils.progress import ProgressInterface
@@ -52,6 +52,19 @@ class ToolBar(QtWidgets.QToolBar):
         self.setIconSize(QtCore.QSize(20, 20))
 
 
+class NormalMessageBox(QtWidgets.QMessageBox):
+    """A message box which enforces normal font."""
+
+    def __init__(self, parent: QtWidgets.QWidget, window_title: str):
+        super().__init__(parent)
+        self.setWindowTitle(window_title)
+        self.setTextFormat(QtCore.Qt.TextFormat.MarkdownText)
+        self.setStyleSheet("font-weight: 500;")
+
+    def set_text_list(self, text: Iterable[str]) -> None:
+        return super().setText("\n\n".join(text))
+
+
 class MandatoryLabel(QtWidgets.QLabel):
     """A label extension which appends a '*' at the end of the label to mark
     the field as required.
@@ -84,20 +97,27 @@ class SelectionButton(QtWidgets.QPushButton):
 class SelectionAction(Action):
     """An action extension which connects this action to a selection model.
 
-    The action is disabled by default. And gets enabled when the selection has,
+    The action is disabled by default, and gets enabled when the selection has,
     at least, one selected row.
     """
 
     def __init__(self, *args: Any, selection_model: QtCore.QItemSelectionModel):
         super().__init__(*args)
         self.setEnabled(False)
+        self._selection_enabled = True
         self._selection_model = selection_model
-        selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
+        self._selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
+
+    def enable_selection(self, enabled: bool) -> None:
+        self._selection_enabled = enabled
+        self.selection_changed()
 
     def selection_changed(self) -> None:
         # Following works better than using 'QItemSelection', especially in
         # cases where multiple selection is possible.
-        self.setEnabled(bool(len(self._selection_model.selectedRows())))
+        self.setEnabled(
+            self._selection_enabled and bool(len(self._selection_model.selectedRows()))
+        )
 
 
 class GuiProgress(QtCore.QObject, ProgressInterface):
@@ -130,9 +150,7 @@ class ConsoleWidget(QtWidgets.QGroupBox, IconRepainterWidget):
         btn_clear_console.clicked.connect(self.clear)  # type: ignore
         layout = QtWidgets.QHBoxLayout(self)
         layout.addWidget(self.textbox)
-        layout.addWidget(
-            btn_clear_console, alignment=cast(QtCore.Qt.Alignment, QtCore.Qt.AlignTop)
-        )
+        layout.addWidget(btn_clear_console, alignment=QtCore.Qt.AlignmentFlag.AlignTop)
 
     def clear(self) -> None:
         self.textbox.clear()
@@ -248,15 +266,20 @@ class BaseTab(IconRepainterWidget):
         self.btn_run.clicked.connect(action)  # type: ignore
         hbox_layout(self.btn_test, self.btn_run, parent=self.run_panel)
 
-    def run_workflow_thread(self, f: Callable[..., Any], **kwargs: Any) -> None:
+    def run_workflow_thread(
+        self,
+        f: Callable[..., Any],
+        signals: Optional[Dict[str, Callable[..., Any]]] = None,
+        **kwargs: Any,
+    ) -> None:
         """Run a thread with predefined signals."""
         self.run_panel.setEnabled(False)
-        signals: Dict[str, Callable[..., Any]] = dict(
-            logging=self.console.write,
-            error=lambda e: self.console.append(str(e[1])),
-            finished=lambda: self.run_panel.setEnabled(True),
-        )
-        run_thread(f, signals=signals, **kwargs)
+        default_signals: Dict[str, Callable[..., Any]] = {
+            "logging": self.console.write,
+            "error": lambda e: self.console.append(str(e[1])),
+            "finished": lambda: self.run_panel.setEnabled(True),
+        }
+        run_thread(f, signals={**default_signals, **(signals or {})}, **kwargs)
 
 
 def get_text_input(
@@ -264,8 +287,10 @@ def get_text_input(
 ) -> Optional[str]:
     dialog = QtWidgets.QDialog(parent)
     dialog.setWindowTitle(APP_NAME_SHORT)
-    buttons = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Cancel)
-    ok_btn = buttons.addButton(QtWidgets.QDialogButtonBox.Ok)
+    buttons = QtWidgets.QDialogButtonBox(
+        QtWidgets.QDialogButtonBox.StandardButton.Cancel
+    )
+    ok_btn = buttons.addButton(QtWidgets.QDialogButtonBox.StandardButton.Ok)
     ok_btn.setEnabled(False)
     buttons.accepted.connect(dialog.accept)  # type: ignore
     buttons.rejected.connect(dialog.reject)  # type: ignore
@@ -274,7 +299,7 @@ def get_text_input(
     if password:
         user_input.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
     vbox_layout(QtWidgets.QLabel(msg), user_input, buttons, parent=dialog)
-    if open_window(dialog) != QtWidgets.QDialog.Accepted:
+    if open_window(dialog) != QtWidgets.QDialog.DialogCode.Accepted:
         return None
     return user_input.text()
 
@@ -285,13 +310,17 @@ def get_pass_input(parent: QtWidgets.QWidget, msg: str) -> Optional[Secret[str]]
 
 
 def warning_callback(
-    title: str, parent: Optional[QtWidgets.QWidget] = None
+    title: str,
+    parent: Optional[QtWidgets.QWidget] = None,
+    msg_prefix: Optional[str] = None,
 ) -> Callable[[str], None]:
     msg_warn = warning_dialog(title, parent=parent)
+    prefix = f"{msg_prefix}\n\n" if msg_prefix else ""
 
     def _show_warning(msg: str) -> None:
         # Add an extra line break so that text is easier to read in GUI.
-        msg_warn.setText(format(msg).replace("\n", "\n\n"))
+        error_msg_from_process = format(msg).replace("\n", "\n\n")
+        msg_warn.setText(prefix + error_msg_from_process)
         open_window(msg_warn)
 
     return _show_warning
@@ -302,7 +331,7 @@ def warning_dialog(
 ) -> QtWidgets.QMessageBox:
     msg = QtWidgets.QMessageBox(parent=parent)
     msg.setWindowTitle(title)
-    msg.setIcon(QtWidgets.QMessageBox.Warning)
+    msg.setIcon(QtWidgets.QMessageBox.Icon.Warning)
     if text is not None:
         msg.setText(text)
     return msg
@@ -314,38 +343,6 @@ def show_warning(
     warning_dialog(title, text, parent).show()
 
 
-def create_verify_dtr_checkbox(
-    app_data: AppData, field_name: str, parent: Optional[QtWidgets.QWidget] = None
-) -> QtWidgets.QCheckBox:
-    verify_dtr = QtWidgets.QCheckBox("Verify DTR ID", parent)
-    verify_dtr.setStatusTip("Verify DTR (Data Transfer Request) ID")
-    verify_dtr.setChecked(not app_data.config.offline and app_data.encrypt_verify_dtr)
-    if app_data.config.offline:
-        verify_dtr.setEnabled(not app_data.config.offline)
-        verify_dtr.setStatusTip(
-            "Verifying Transfer Request ID in offline mode is not possible."
-        )
-    verify_dtr.stateChanged.connect(  # type: ignore
-        lambda state: setattr(app_data, field_name, state == QtCore.Qt.Checked)
-    )
-    return verify_dtr
-
-
-def create_verify_filename_checkbox(
-    app_data: AppData, field_name: str, parent: Optional[QtWidgets.QWidget] = None
-) -> QtWidgets.QCheckBox:
-    verify_filename = QtWidgets.QCheckBox("Verify package name", parent)
-    verify_filename.setStatusTip(
-        "Verify that the name of packages to transfer follows the package "
-        "naming convention."
-    )
-    verify_filename.setChecked(app_data.config.verify_package_name)
-    verify_filename.stateChanged.connect(  # type: ignore
-        lambda state: setattr(app_data, field_name, state == QtCore.Qt.Checked)
-    )
-    return verify_filename
-
-
 def create_slider(
     minimum: int,
     maximum: int,
@@ -357,7 +354,7 @@ def create_slider(
 ) -> Tuple[QtWidgets.QSlider, QtWidgets.QLabel]:
     widget_value = QtWidgets.QLabel(str(initial_value))
 
-    slider = QtWidgets.QSlider(QtCore.Qt.Horizontal)
+    slider = QtWidgets.QSlider(QtCore.Qt.Orientation.Horizontal)
     slider.setMinimum(minimum)
     slider.setMaximum(maximum)
     slider.setValue(initial_value)
@@ -365,7 +362,7 @@ def create_slider(
     if status_tip is not None:
         slider.setStatusTip(status_tip)
     if show_ticks:
-        slider.setTickPosition(QtWidgets.QSlider.TicksBelow)
+        slider.setTickPosition(QtWidgets.QSlider.TickPosition.TicksBelow)
 
     def update_text(value: int) -> None:
         widget_value.setText(str(value))
@@ -407,7 +404,7 @@ def layout_add(
 
 
 def grid_layout(
-    *widgets: Sequence[Optional[Union[QtWidgets.QWidget, GridLayoutCell]]],
+    *widgets: Sequence[Union[QtWidgets.QWidget, GridLayoutCell, None]],
     parent: Optional[QtWidgets.QWidget] = None,
     min_col_width: Optional[Sequence[int]] = None,
 ) -> QtWidgets.QGridLayout:
