@@ -54,7 +54,9 @@ class DecryptTab(BaseTab):
         decompress.setChecked(not self.app_data.decrypt_decrypt_only)
         decompress.stateChanged.connect(  # type: ignore
             lambda state: setattr(
-                self.app_data, "decrypt_decrypt_only", state == QtCore.Qt.Unchecked
+                self.app_data,
+                "decrypt_decrypt_only",
+                QtCore.Qt.CheckState(state) == QtCore.Qt.CheckState.Unchecked,
             )
         )
 
