@@ -1,5 +1,5 @@
 from functools import partial, wraps
-from typing import Any, cast
+from typing import Any, Optional, cast
 
 from .component import (
     BaseTab,
@@ -9,7 +9,6 @@ from .component import (
     get_pass_input,
     SelectionButton,
     MandatoryLabel,
-    create_verify_dtr_checkbox,
     LineEdit,
     grid_layout,
     GridLayoutCell,
@@ -30,9 +29,9 @@ ignore_disk_space_error_label = "Ignore disk space error"
 
 
 @wraps(encrypt.encrypt)
-def encrypt_workflow(*args: str, **kwargs: Any) -> None:
+def encrypt_workflow(*args: str, **kwargs: Any) -> Optional[str]:
     try:
-        encrypt.encrypt(*args, **kwargs)
+        return encrypt.encrypt(*args, **kwargs)
     except OutOfSpaceError as e:
         raise OutOfSpaceError(
             f"{e} Use the checkbox '{ignore_disk_space_error_label}' in the "
@@ -50,8 +49,14 @@ class EncryptTab(BaseTab):
         self.create_run_panel(
             "Package and encrypt data", self.encrypt, "Package && Encrypt"
         )
-        self.app_data.add_listener("encrypt_files", self._enable_buttons)
-        self.app_data.add_listener("encrypt_recipients", self._enable_buttons)
+        for field in (
+            "encrypt_files",
+            "encrypt_recipients",
+            "encrypt_transfer_id",
+            "encrypt_purpose",
+        ):
+            self.app_data.add_listener(field, self._enable_buttons)
+            self.app_data.config.add_listener("verify_dtr", self._enable_buttons)
         self.create_console()
         self.create_progress_bar()
 
@@ -68,6 +73,17 @@ class EncryptTab(BaseTab):
         self.set_buttons_enabled(
             len(self.app_data.encrypt_recipients) > 0
             and len(self.app_data.encrypt_files) > 0
+            and (
+                not self.app_data.config.verify_dtr
+                or (
+                    self.app_data.config.verify_dtr
+                    and self.app_data.encrypt_transfer_id is not None
+                )
+            )
+            and (
+                self.app_data.encrypt_transfer_id is None
+                or self.app_data.encrypt_purpose is not None
+            )
         )
 
     def create_files_panel(self) -> QtWidgets.QGroupBox:
@@ -92,10 +108,12 @@ class EncryptTab(BaseTab):
         recipients_output_view.setModel(recipients_output_model)
         recipients_output_view.verticalHeader().hide()
         recipients_output_view.horizontalHeader().setSectionResizeMode(
-            QtWidgets.QHeaderView.ResizeToContents
+            QtWidgets.QHeaderView.ResizeMode.ResizeToContents
         )
         recipients_output_view.horizontalHeader().setStretchLastSection(True)
-        recipients_output_view.setSelectionBehavior(QtWidgets.QTableView.SelectRows)
+        recipients_output_view.setSelectionBehavior(
+            QtWidgets.QTableView.SelectionBehavior.SelectRows
+        )
         recipients_output_view.setSelectionMode(
             QtWidgets.QTableView.SelectionMode.SingleSelection
         )
@@ -161,9 +179,13 @@ class EncryptTab(BaseTab):
             (MandatoryLabel("Sender"), sender_widget),
             (None, recipients_input_view, recipients_btn_add),
             (
-                GridLayoutCell(MandatoryLabel("Recipients"), align=QtCore.Qt.AlignTop),
+                GridLayoutCell(
+                    MandatoryLabel("Recipients"), align=QtCore.Qt.AlignmentFlag.AlignTop
+                ),
                 recipients_output_view,
-                GridLayoutCell(recipients_btn_remove, align=QtCore.Qt.AlignTop),
+                GridLayoutCell(
+                    recipients_btn_remove, align=QtCore.Qt.AlignmentFlag.AlignTop
+                ),
             ),
             parent=group_box,
         )
@@ -231,7 +253,7 @@ class EncryptTab(BaseTab):
             lambda state: setattr(
                 self.app_data,
                 "encrypt_ignore_disk_space_error",
-                state == QtCore.Qt.Checked,
+                QtCore.Qt.CheckState(state) == QtCore.Qt.CheckState.Checked,
             )
         )
         grid_layout(
@@ -251,22 +273,34 @@ class EncryptTab(BaseTab):
         """Create a group box with data transfer request (DTR) related fields."""
 
         group_box = QtWidgets.QGroupBox("Data transfer info")
+        required_suffix = "<sup><font color='red'>*</font></sup>"
 
-        # Create fields.
+        transfer_id_label = QtWidgets.QLabel("DTR ID")
         transfer_id = LineEdit()
-        transfer_id.setStatusTip("(optional) Data Transfer Request ID")
-        transfer_id.setValidator(QtGui.QIntValidator(1, 10**9))
-        verify_dtr = create_verify_dtr_checkbox(
-            self.app_data, "encrypt_verify_dtr", group_box
+        transfer_id.setStatusTip(
+            "Data Transfer Request ID (optional if Verify DTR is disabled in settings)"
         )
+        transfer_id.setValidator(QtGui.QIntValidator(1, 10**9))
+        purpose_label = QtWidgets.QLabel("Purpose")
         purpose = QtWidgets.QComboBox(group_box)
-        purpose.setStatusTip("(optional) Purpose of the package")
+        purpose.setStatusTip("Purpose of the package (required if DTR ID is specified)")
         purpose.addItems(("",) + tuple(x.name for x in Purpose))
         purpose.setCurrentText("")
 
-        # Add actions.
+        def on_verify_dtr_changed() -> None:
+            transfer_id_label.setText(
+                "DTR ID" + (required_suffix if self.app_data.config.verify_dtr else "")
+            )
+
+        self.app_data.config.add_listener("verify_dtr", on_verify_dtr_changed)
+
         def on_transfer_id_changed(text: str) -> None:
-            self.app_data.encrypt_transfer_id = int(text) if text else None
+            if text:
+                self.app_data.encrypt_transfer_id = int(text)
+                purpose_label.setText(f"Purpose{required_suffix}")
+            else:
+                self.app_data.encrypt_transfer_id = None
+                purpose_label.setText("Purpose")
 
         transfer_id.textChanged.connect(on_transfer_id_changed)  # type: ignore
         purpose.currentTextChanged.connect(  # type: ignore
@@ -275,9 +309,8 @@ class EncryptTab(BaseTab):
             )
         )
         grid_layout(
-            (QtWidgets.QLabel("DTR ID"), transfer_id),
-            (GridLayoutCell(verify_dtr, span=2),),
-            (QtWidgets.QLabel("Purpose"), purpose),
+            (transfer_id_label, transfer_id),
+            (purpose_label, purpose),
             parent=group_box,
         )
         return group_box
@@ -289,6 +322,15 @@ class EncryptTab(BaseTab):
                 return
         else:
             pw = None
+
+        def update_transfer_files(path: Optional[str]) -> None:
+            if path is not None:
+                self.app_data.transfer_files.setStringList([path])
+                self.app_data.transfer_files.layoutChanged.emit()  # type: ignore
+                self.console.append(
+                    "<strong>Added the newly created package to the 'Transfer' tab.</strong>"
+                )
+
         self.run_workflow_thread(
             encrypt_workflow,
             f_kwargs=dict(
@@ -297,7 +339,6 @@ class EncryptTab(BaseTab):
                 sender=self.app_data.encrypt_sender,
                 recipient=self.app_data.encrypt_recipients,
                 dtr_id=self.app_data.encrypt_transfer_id,
-                verify_dtr=self.app_data.encrypt_verify_dtr,
                 config=self.app_data.config,
                 passphrase=pw,
                 output=self.app_data.encrypt_output_location,
@@ -307,6 +348,7 @@ class EncryptTab(BaseTab):
                 purpose=self.app_data.encrypt_purpose,
                 progress=GuiProgress(self.progress_bar.setValue),
             ),
+            signals={"result": update_transfer_files},
             ignore_exceptions=True,
             report_config=self.app_data.config,
             force=self.app_data.encrypt_ignore_disk_space_error,
