@@ -17,17 +17,21 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
     """File selection widget."""
 
     def __init__(
-        self, title: str, parent: QtWidgets.QWidget, name_filter: Optional[str] = None
+        self,
+        title: str,
+        parent: QtWidgets.QWidget,
+        name_filter: Optional[str] = None,
+        model: Optional[QtCore.QStringListModel] = None,
     ):
         super().__init__(parent)
         self.path = str(Path.home())
         self.name_filter = name_filter
 
-        self.file_list_model = QtCore.QStringListModel()
+        self.file_list_model = model or QtCore.QStringListModel()
         self.file_list_view = QtWidgets.QListView(self)
         self.file_list_view.setModel(self.file_list_model)
         self.file_list_view.setSelectionMode(
-            QtWidgets.QAbstractItemView.ExtendedSelection
+            QtWidgets.QAbstractItemView.SelectionMode.ExtendedSelection
         )
         self.file_list_view.setLayout(QtWidgets.QVBoxLayout())
 
@@ -111,20 +115,25 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
 
     def _add_files(self) -> None:
         dialog = QtWidgets.QFileDialog(self)
-        dialog.setFileMode(QtWidgets.QFileDialog.ExistingFiles)
+        dialog.setFileMode(QtWidgets.QFileDialog.FileMode.ExistingFiles)
         dialog.setDirectory(str(self.path))
         if self.name_filter:
             dialog.setNameFilter(self.name_filter)
             dialog.selectNameFilter(self.name_filter)
-        if open_window(dialog) == QtWidgets.QDialog.Accepted:
+        if open_window(dialog) == QtWidgets.QDialog.DialogCode.Accepted:
             self._update_paths(dialog.selectedFiles())
 
 
 class DirectoryAndFileSelectionWidget(FileSelectionWidget):
     """File selection widget extension adding directory selection."""
 
-    def __init__(self, title: str, parent: QtWidgets.QWidget):
-        super().__init__(title, parent)
+    def __init__(
+        self,
+        title: str,
+        parent: QtWidgets.QWidget,
+        model: Optional[QtCore.QStringListModel] = None,
+    ):
+        super().__init__(title, parent, model=model)
 
     def _create_layout(self, allow_dirs: bool = True) -> None:
         super()._create_layout(allow_dirs=allow_dirs)
@@ -149,8 +158,15 @@ class DirectoryAndFileSelectionWidget(FileSelectionWidget):
 class ArchiveOnlyFileSelectionWidget(FileSelectionWidget):
     """File selection widget extension for selecting ZIP and TAR archives only."""
 
-    def __init__(self, title: str, parent: QtWidgets.QWidget):
-        super().__init__(title, parent, name_filter="Archives (*.zip *.tar)")
+    def __init__(
+        self,
+        title: str,
+        parent: QtWidgets.QWidget,
+        model: Optional[QtCore.QStringListModel] = None,
+    ):
+        super().__init__(
+            title, parent, name_filter="Archives (*.zip *.tar)", model=model
+        )
 
     def dropEvent(self, event: QtGui.QDropEvent) -> None:
         paths = [
