@@ -1,5 +1,5 @@
 from collections import defaultdict
-from typing import Callable, Any, Dict
+from typing import Callable, Any, Dict, Generic, TypeVar
 
 
 class Listener:
@@ -10,9 +10,6 @@ class Listener:
     def set_value(self, attr: str, val: Any) -> None:
         """Abstracts __setitem__, __setattr__"""
 
-    def get_value(self, attr: str) -> Any:
-        """Abstracts __getitem__, __getattr__"""
-
     def _trigger(self, attr: str) -> None:
         if not hasattr(self, "_listeners"):
             # This is necessary, as this class will be subclassed by dataclasses
@@ -39,32 +36,35 @@ class ClassWithListener(Listener):
     def set_value(self, attr: str, val: Any) -> None:
         super().__setattr__(attr, val)
 
-    def get_value(self, attr: str) -> Any:
-        return getattr(self, attr)
-
     def __setattr__(self, attr: str, val: Any) -> None:
         self._set(attr, val)
 
 
-class ListenerWrap(Listener):
+T = TypeVar("T")
+
+
+class ListenerWrap(Listener, Generic[T]):
     """Wrapper around an object to listen to."""
 
-    def __init__(self, obj: Any) -> None:
+    def __init__(self, obj: T) -> None:
         super().__init__()
         self._target = obj
 
     def set_value(self, attr: str, val: Any) -> None:
         setattr(self._target, attr, val)
 
-    def get_value(self, attr: str) -> Any:
+    def __getattr__(self, attr: str) -> Any:
         return getattr(self._target, attr)
 
+    def __eq__(self, other: Any) -> bool:
+        return bool(self._target == other)
+
     @property
-    def target(self) -> Any:
+    def target(self) -> T:
         return self._target
 
     @target.setter
-    def target(self, value: Any) -> None:
+    def target(self, value: T) -> None:
         self._target = value
         self._trigger_all()
 
