@@ -10,15 +10,15 @@ from sett import (
     URL_GITLAB,
     VERSION_WITH_DEPS,
 )
-from .component import show_warning, is_macos
+from .component import show_warning, is_macos, NormalMessageBox
 from .decrypt_tab import DecryptTab
 from .encrypt_tab import EncryptTab
-from .theme import Icon, IconRepainter, Action, IconRepainterWidget
 from .keys_tab import KeysTab
-from .model import AppData
+from .model import AppData, ConfigProxy
 from .parallel import run_thread
 from .pyside import QtCore, QtGui, QtWidgets, open_window
 from .settings_tab import SettingsTab
+from .theme import Icon, IconRepainter, Action, IconRepainterWidget
 from .transfer_tab import TransferTab
 from ..core.versioncheck import check_version
 from ..utils.config import Config, load_config, save_config, config_to_dict
@@ -41,7 +41,7 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
     def __init__(self, icon_repainter: IconRepainter) -> None:
         super().__init__()
         self._icon_repainter = icon_repainter
-        self.app_data = AppData(config=self.load_config_from_disk())
+        self.app_data = AppData(config=ConfigProxy(self.load_config_from_disk()))
         self.tabs = (
             Tab(":icon/feather/lock.png", "&Encrypt", EncryptTab),
             Tab(":icon/feather/send.png", "&Transfer", TransferTab),
@@ -76,7 +76,10 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
                 tab.label,
             )
         self.icon_repainter().register(self.repaint_tab_icons)
-        self.setCentralWidget(tab_widget)
+        scrollArea = QtWidgets.QScrollArea(self)
+        scrollArea.setWidget(tab_widget)
+        scrollArea.setWidgetResizable(True)
+        self.setCentralWidget(scrollArea)
 
     def repaint_tab_icons(self) -> None:
         for i, tab in enumerate(self.tabs):
@@ -103,7 +106,9 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
 
         action_help = Action(":icon/feather/book-open.png", "&Documentation", self)
         action_help.setStatusTip("Open online documentation")
-        action_help.setShortcut(QtGui.QKeySequence(QtGui.QKeySequence.HelpContents))
+        action_help.setShortcut(
+            QtGui.QKeySequence(QtGui.QKeySequence.StandardKey.HelpContents)
+        )
         action_help.triggered.connect(open_url(URL_READTHEDOCS))  # type: ignore
 
         action_bug_report = Action(
@@ -124,37 +129,53 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
     def closeEvent(self, event: QtGui.QCloseEvent) -> None:
         """Code that is run when the application is closed by the user."""
 
+        # Clear focus on the currently selected widget. This is only needed
+        # for the case where a user exits the app while still having the
+        # focus on field in the Settings Tab.
+        self.focusWidget().clearFocus()
+
         # Compare the current in-memory config values to those present on disk
         # (in the user's config file). If they differ, ask the user whether
         # they want to save their config value modifications to disk.
         if self.app_data.config != self.load_config_from_disk():
-            reply = QtWidgets.QMessageBox.question(
-                self,
-                "Persist changed settings?",
-                "You made changes to settings you did not persist yet.\n"
-                "Do you want to permanently persist them to your sett "
-                "configuration file?",
-                QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
-                QtWidgets.QMessageBox.No,
+            msg = NormalMessageBox(self, "Persist changed settings?")
+            msg.set_text_list(
+                (
+                    "You made changes to settings you did not persist yet.",
+                    "Do you want to permanently save them to your sett "
+                    "configuration file?",
+                )
             )
-            if reply == QtWidgets.QMessageBox.Yes:
-                save_config(config_to_dict(self.app_data.config))
+            msg.setStandardButtons(
+                QtWidgets.QMessageBox.StandardButton.Cancel
+                | QtWidgets.QMessageBox.StandardButton.No
+                | QtWidgets.QMessageBox.StandardButton.Yes
+            )
+            msg.setDefaultButton(QtWidgets.QMessageBox.StandardButton.No)
+            msg.setIcon(QtWidgets.QMessageBox.Icon.Question)
+            reply = open_window(msg)
+            if reply == QtWidgets.QMessageBox.StandardButton.Cancel:
+                event.ignore()
+                return
+            if reply == QtWidgets.QMessageBox.StandardButton.Yes:
+                save_config(config_to_dict(self.app_data.config.get_config()))
 
         if self.app_data.config.gui_quit_confirmation:
             reply = QtWidgets.QMessageBox.question(
                 self,
                 "Quit",
                 "Do you really want to quit?",
-                QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
-                QtWidgets.QMessageBox.No,
+                QtWidgets.QMessageBox.StandardButton.Yes
+                | QtWidgets.QMessageBox.StandardButton.No,
+                QtWidgets.QMessageBox.StandardButton.No,
             )
-            if reply == QtWidgets.QMessageBox.Yes:
+            if reply == QtWidgets.QMessageBox.StandardButton.Yes:
                 event.accept()
             else:
                 event.ignore()
 
     def check_version(self) -> None:
-        if self.app_data.config.offline or not self.app_data.config.check_version:
+        if not self.app_data.config.check_version:
             return
 
         def get_warnings() -> str:
@@ -175,7 +196,7 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
         msg = QtWidgets.QMessageBox(parent=self)
         msg.setWindowTitle("About")
         msg.setIconPixmap(QtGui.QPixmap(":icon/biomedit_logo.png"))
-        msg.setTextFormat(QtCore.Qt.RichText)
+        msg.setTextFormat(QtCore.Qt.TextFormat.RichText)
         msg.setText(
             f"{APP_NAME_LONG}<br>"
             f"{VERSION_WITH_DEPS}<br><br>"
@@ -205,7 +226,7 @@ def open_url(url: str) -> Callable[[], None]:
             msg_warn = QtWidgets.QMessageBox()
             msg_warn.setWindowTitle("Warning")
             msg_warn.setText(f"Unable to open URL at \n{url}.")
-            msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
+            msg_warn.setIcon(QtWidgets.QMessageBox.Icon.Warning)
             open_window(msg_warn)
 
     return open_url_template
