@@ -1,9 +1,23 @@
 import re
-from dataclasses import Field, asdict, fields  # pylint: disable=unused-import
-from typing import Optional, Tuple, Union, Dict, Callable, Sequence, Any, cast
+from dataclasses import Field, asdict, fields
+from itertools import chain, repeat
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+)
 
+from sett.utils.get_config_path import get_config_file
 from sett.utils.validation import REGEX_FQDN, REGEX_IP
 from .component import (
+    NormalMessageBox,
     PathInput,
     create_slider,
     LineEdit,
@@ -11,11 +25,9 @@ from .component import (
     grid_layout,
     GridLayoutCell,
 )
+from .model import AppData, ConfigProxy
+from .pyside import QtCore, QtGui, QtWidgets, open_window
 from .theme import Icon, IconRepainterWidget, PushButton
-from .keys_refresh import load_authority_key_threaded
-from .listener import Listener
-from .model import AppData
-from .pyside import QtCore, QtGui, QtWidgets
 from .ui_model_bind import (
     bind,
     TextControl,
@@ -27,56 +39,34 @@ from ..utils import config
 from ..utils.config import Config, FileType
 
 
-class ConfigProxy(Listener):
-    """Proxy between the Config dataclass and the UI."""
+def align(
+    items: Sequence[Sequence[Sequence[Any]]],
+) -> Iterator[Tuple[Optional[Any], ...]]:
+    """Align a table where items have different lengths.
 
-    def __init__(self, app_data: AppData):
-        super().__init__()
-        self.app_data = app_data
-
-    def set_value(self, attr: str, val: Any) -> None:
-        """Updates the specified sett config attribute (attr) with a new value."""
-        cfg = self.app_data.config
-        if val != getattr(cfg, attr):
-            setattr(cfg, attr, val)
-            if attr == "key_authority_fingerprint":
-                # Only attempt to reload the key validation authority key if
-                # a proper fingerprint was entered. Otherwise we get a warning
-                # each time the user is entering a new character in the field.
-                if len(val) == 40:
-                    load_authority_key_threaded(self.app_data)
-                else:
-                    self.app_data.validation_authority_key = None
-
-    def get_value(self, attr: str) -> Any:
-        return getattr(self.app_data.config, attr)
-
-    def refresh(self) -> None:
-        for callbacks in self._listeners.values():
-            for callback in callbacks:
-                callback()
-
-    def set_config(self, cfg: Config) -> None:
-        """Sets/Updates the in-memory config values with the new values passed
-        in "cfg". Then updates the Settings Tab widgets in the UI.
-        """
-        self.app_data.config = cfg
-        self.refresh()
-
-    def get_config(self) -> Config:
-        """Returns the current in-memory config values."""
-        cfg: Config = self.app_data.config
-        return cfg
+    Given a 2-dimensional array of sequences of different lengths, yield
+    tuples of equal length where shorter sequences are filled with `None`s
+    to reach the length of the longest sequence.
+    """
+    longest = max((len(col) for row in items for col in row), default=0)
+    for row in items:
+        aligned: List[Any] = []
+        for col in row:
+            aligned.extend(chain(col, repeat(None, longest - len(col))))
+        yield tuple(aligned)
 
 
 class SettingsTab(IconRepainterWidget):
+    """Class that builds the tab where users can modify the settings of their
+    application.
+    """
+
     persist_btn_text = "Save to config file"
     persist_btn_icon_file_name = ":icon/feather/save.png"
 
     def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
         super().__init__(parent=parent)
-        self.app_data = app_data
-        self.config_proxy = ConfigProxy(self.app_data)
+        self.config_proxy = app_data.config
 
         widget_register: Dict[str, QtWidgets.QWidget] = {}
         cfg_fields = {f.name: f for f in fields(Config)}
@@ -89,47 +79,61 @@ class SettingsTab(IconRepainterWidget):
                 widget_register=widget_register,
             )
 
-        self.setLayout(
+        def label_field(text: str) -> GridLayoutCell:
+            font = QtGui.QFont()
+            font.setBold(True)
+            font.setPointSize(round(font.pointSize() * 1.3))
+            label = QtWidgets.QLabel(text)
+            label.setFont(font)
+            return GridLayoutCell(
+                label,
+                span=8,
+                align=QtCore.Qt.AlignmentFlag.AlignBottom,
+            )
+
+        layout = QtWidgets.QVBoxLayout()
+        layout.setAlignment(QtCore.Qt.AlignmentFlag.AlignTop)
+        layout.addLayout(self._header())
+        layout.addSpacing(20)
+        layout.addLayout(
             grid_layout(
-                self._header(),
-                group_box(
-                    "Data encryption / decryption settings",
-                    cfg_field("compression_level"),
-                    cfg_field("max_cpu"),
-                    cfg_field("default_sender"),
-                    cfg_field("sign_encrypted_data"),
-                    cfg_field("always_trust_recipient_key"),
-                    cfg_field("output_dir"),
-                    cfg_field("offline"),
-                    cfg_field("package_name_suffix"),
-                ),
-                group_box(
-                    "PGP keys",
-                    cfg_field("key_authority_fingerprint"),
-                    cfg_field("gpg_home_dir"),
-                    cfg_field("keyserver_url"),
-                    cfg_field("gpg_key_autodownload"),
-                ),
-                group_box(
-                    "Data transfer",
-                    cfg_field("ssh_password_encoding"),
-                    cfg_field("dcc_portal_url"),
-                    cfg_field("verify_package_name"),
-                    cfg_field("sftp_buffer_size"),
-                ),
-                group_box(
-                    "sett updates", cfg_field("repo_url"), cfg_field("check_version")
-                ),
-                group_box(
-                    "Miscellaneous and logs",
-                    cfg_field("gui_quit_confirmation"),
-                    cfg_field("log_dir"),
-                    cfg_field("log_max_file_number"),
-                    cfg_field("error_reports"),
-                ),
-                self._footer(),
+                *align(
+                    (
+                        ((label_field("Data encryption / decryption"),), ()),
+                        (cfg_field("compression_level"), cfg_field("max_cpu")),
+                        (cfg_field("verify_dtr"), cfg_field("default_sender")),
+                        (
+                            cfg_field("always_trust_recipient_key"),
+                            cfg_field("output_dir"),
+                        ),
+                        (
+                            cfg_field("sign_encrypted_data"),
+                            cfg_field("package_name_suffix"),
+                        ),
+                        ((label_field("PGP keys"),), ()),
+                        (cfg_field("gpg_key_autodownload"), cfg_field("keyserver_url")),
+                        (cfg_field("verify_key_approval"), cfg_field("gpg_home_dir")),
+                        ((label_field("Data transfer"),), ()),
+                        (cfg_field("dcc_portal_url"), cfg_field("sftp_buffer_size")),
+                        (
+                            cfg_field("verify_package_name"),
+                            cfg_field("ssh_password_encoding"),
+                        ),
+                        ((label_field("Miscellaneous"),), ()),
+                        (cfg_field("repo_url"), cfg_field("log_dir")),
+                        (cfg_field("check_version"), cfg_field("log_max_file_number")),
+                        (
+                            cfg_field("gui_quit_confirmation"),
+                            cfg_field("error_reports"),
+                        ),
+                    )
+                )
             )
         )
+        layout.addStretch()
+        layout.addWidget(self._footer())
+        self.setLayout(layout)
+
         # Enable or disable the PGP key auto-download checkbox option based on
         # whether a keyserver URL value is provided or not.
         self.checkbox_gpg_key_autodownload = cast(
@@ -148,10 +152,14 @@ class SettingsTab(IconRepainterWidget):
     def _save_config_to_disk(self) -> None:
         """Write the current in-app config values to a config file on disk."""
         config.save_config(config.config_to_dict(self.config_proxy.get_config()))
+        msg = NormalMessageBox(parent=self, window_title="Settings")
+        msg.setIcon(QtWidgets.QMessageBox.Icon.Information)
+        msg.setText(f'Successfully saved settings to "{get_config_file()}"')
+        open_window(msg)
 
     def _header(
         self,
-    ) -> Tuple[GridLayoutCell, QtWidgets.QPushButton, QtWidgets.QPushButton]:
+    ) -> QtWidgets.QGridLayout:
         top_label = QtWidgets.QLabel(
             "Changes you make are applied instantly during the current session.\n"
             f"To persist changes across restarts, make sure to click the "
@@ -169,15 +177,21 @@ class SettingsTab(IconRepainterWidget):
         defaults_btn.clicked.connect(  # type: ignore
             lambda: self.config_proxy.set_config(config.default_config())
         )
-        return (GridLayoutCell(top_label, span=2), reset_btn, defaults_btn)
+        layout = QtWidgets.QGridLayout()
+        layout.addWidget(top_label, 0, 0, 1, 2)
+        layout.addWidget(reset_btn, 0, 2)
+        layout.addWidget(defaults_btn, 0, 3)
+        return layout
 
-    def _footer(self) -> Tuple[GridLayoutCell]:
+    def _footer(self) -> PushButton:
         self.persist_btn = PushButton(
-            self.persist_btn_icon_file_name, self.persist_btn_text, self
+            self.persist_btn_icon_file_name,
+            f'{self.persist_btn_text} "{get_config_file()}"',
+            self,
         )
         self.persist_btn.setStatusTip("Saves your current settings to the config file")
         self.persist_btn.clicked.connect(self._save_config_to_disk)  # type: ignore
-        return (GridLayoutCell(self.persist_btn, span=4),)
+        return self.persist_btn
 
     def _enable_checkbox_key_autodownload(self) -> None:
         self.checkbox_gpg_key_autodownload.setEnabled(
@@ -188,33 +202,32 @@ class SettingsTab(IconRepainterWidget):
         self.persist_btn.setIcon(Icon(self.persist_btn_icon_file_name))
 
 
-def group_box(
-    name: str, *widgets: Sequence[Optional[Union[QtWidgets.QWidget, GridLayoutCell]]]
-) -> Tuple[GridLayoutCell]:
-    box = QtWidgets.QGroupBox(name)
-    box.setLayout(grid_layout(*widgets, parent=box, min_col_width=(0, 180)))
-    return (GridLayoutCell(box, span=4),)
-
-
-def check_hostname(
-    regex: str, widget: LineEdit, config_key: str, status_tip: str
-) -> None:
+def check_hostname(regex: str, widget: LineEdit, status_tip: str) -> None:
     """Verify that the URL entered in the specified widget is valid.
     * If the URL is not valid, the cell is colored in red and an error is
-      displayed as tooltip.
+      displayed as tooltip (StatusTip).
     * Minor errors (e.g. using :/ instead of :// after the scheme) are
       auto-corrected.
     """
 
+    # Retrieve the name of the config setting associated with the widget.
+    config_key = widget.objectName()
+
     def display_error_in_widget(error_msg: str) -> None:
-        # Change the background color and status tip of the LineEdit widget to
-        # display an error to the user.
+        """Change the background color and status tip of the LineEdit widget
+        to display an error to the user.
+        """
         widget.setStyleSheet(f"#{config_key} {{background-color:red;}}")
         widget.setStatusTip(error_msg)
 
+    # Get the URL value from the widget. Empty values are allowed (nothing to
+    # check in that case)
+    url = widget.text().strip()
+    if not url:
+        return
+
     # Verify that a valid scheme is given by the user.
     # If no scheme is given, https:// is added by default.
-    url = widget.text().strip()
     scheme, *_ = re.split(r"://|:/", url)
     if not _:
         hostname = scheme
@@ -233,30 +246,88 @@ def check_hostname(
         return
 
     # Update widget text to the (possibly) corrected URL value.
+    # Note: the StatusTip is here set again for the case when the field
+    # earlier contained an error and still has the error message as StatusTip.
     widget.setText(scheme + "://" + hostname)
     widget.setStyleSheet(f"#{config_key} {{}}")
     widget.setStatusTip(status_tip)
 
 
+def reset_to_default_if_empty(widget: LineEdit) -> None:
+    """Check whether the given free text `widget` (of type LineEdit) is empty,
+    and if so, fill the widget with the default value of the setting that it
+    holds.
+    Additionally, warn the user that the setting has been reset via a pop-up.
+
+    :param widget: text widget whose text is to be reset.
+    """
+    if not widget.text().strip():
+
+        # Reset the in-memory value (AppData) and widget text to the default
+        # value of the setting.
+        config_key = widget.objectName()
+        widget.setText(Config.get_default_value(config_key))
+        widget.editingFinished.emit()  # type: ignore
+
+        # Generate a pop-up that warns the user that the field has been
+        # reset to its default value.
+        msg = NormalMessageBox(
+            parent=widget.parent(), window_title="Mandatory field warning"  # type: ignore
+        )
+        msg.setIcon(QtWidgets.QMessageBox.Icon.Warning)
+        msg.setText(
+            f"The field '{Config.get_label(config_key)}' ('{config_key}' "
+            "in the config file) is mandatory and cannot be left empty.\n\n"
+            "The field was reset to its default value."
+        )
+        open_window(msg)
+
+
 def widget_str(
     config_proxy: ConfigProxy,
     config_key: str,
     status_tip: str,
     regex: Optional[str] = None,
 ) -> Tuple[QtWidgets.QWidget, ...]:
+    """Return a text widget (LineEdit) associated with the specified setting
+    `config_key`. The widget has the following behavior:
+     * The status tip of the widget is set to status_tip.
+     * When edited by the user, the content of the text field is checked to
+       make sure the input complies with the (optionally) specified regexp
+       `regex`.
+     * For settings that are mandatory, if the user clears the content of the
+       widget without providing any value, the widget is reset to its default
+       value.
+    """
+
     widget = LineEdit()
     widget.setStatusTip(status_tip)
     bind(config_proxy, config_key, widget, TextControl)
-    if regex:
-        widget.setObjectName(config_key)
-        if regex == REGEX_FQDN:
-            widget.editingFinished.connect(  # type: ignore
-                lambda: check_hostname(regex, widget, config_key, status_tip)
-            )
-        else:
-            widget.setValidator(
-                QtGui.QRegularExpressionValidator(QtCore.QRegularExpression(regex))
-            )
+    widget.setObjectName(config_key)
+
+    # If the setting is mandatory (i.e. `None` is not allowed as a value), a
+    # check for resetting empty values to their default value is added to the
+    # actions to perform after a field was edited by the user.
+    if Config.is_mandatory_argument(config_key):
+        widget.editingFinished.connect(lambda: reset_to_default_if_empty(widget))  # type: ignore
+
+    # Add regexp-based validation rules to the field. These rules are either
+    # added via a post-edit check (i.e. when the user leaves the field, see
+    # Case 1 below), or via a "Validator" (checks the value at every keystroke
+    # from the user, see Case 2 below).
+    # Case 1: the field uses REGEX_FQDN as validator regexp, meaning that
+    #         it contains a URL (FQDN = fully qualified domain name).
+    if regex == REGEX_FQDN:
+        # A check for the validity of the specified domain name is added.
+        widget.editingFinished.connect(  # type: ignore
+            lambda: check_hostname(regex, widget, status_tip)
+        )
+    # Case 2: the field is not a URL, but it has some specific validation
+    #         rules given as a regexp.
+    elif regex is not None:
+        widget.setValidator(
+            QtGui.QRegularExpressionValidator(QtCore.QRegularExpression(regex))
+        )
 
     return (widget,)
 
@@ -268,12 +339,12 @@ def widget_path(
     file_type: FileType,
     parent: IconRepainterWidget,
 ) -> Tuple[QtWidgets.QWidget, ...]:
+    """Return a path widget associated with the specified setting `config_key`."""
     widget = PathInput(
         directory=file_type is FileType.directory, path=None, parent=parent
     )
     widget.setStatusTip(status_tip)
     bind(config_proxy, config_key, widget, PathControl)
-
     return (widget.text, widget.btn, widget.btn_clear)
 
 
@@ -282,10 +353,12 @@ def widget_bool(
     config_key: str,
     status_tip: str,
 ) -> Tuple[QtWidgets.QWidget, ...]:
+    """Return a check-box widget associated with the specified boolean setting
+    `config_key`.
+    """
     widget = QtWidgets.QCheckBox()
     widget.setStatusTip(status_tip)
     bind(config_proxy, config_key, widget, BoolControl)
-
     return (widget,)
 
 
@@ -296,6 +369,10 @@ def widget_int(
     minimum: Optional[int] = None,
     maximum: Optional[int] = None,
 ) -> Tuple[QtWidgets.QWidget, ...]:
+    """Return a spin-box widget (a field for integer values with arrows to
+    increase/decrease the value) associated with the specified setting
+    `config_key`.
+    """
     widget = SpinBox()
     widget.setStatusTip(status_tip)
     if minimum is not None:
@@ -303,7 +380,6 @@ def widget_int(
     if maximum is not None:
         widget.setMaximum(maximum)
     bind(config_proxy, config_key, widget, NumericControl)
-
     return (widget,)
 
 
@@ -314,10 +390,16 @@ def widget_int_range(
     minimum: int,
     maximum: int,
 ) -> Tuple[QtWidgets.QWidget, ...]:
+    """Return a slider widget that allows to select integer values associated
+    with the specified setting `config_key`.
+
+    The slider has a specified range [minimum - maximum]. This widget only
+    makes sense when the range of values is not too large, typically <= 25.
+    """
     slider, slider_value = create_slider(
         minimum=minimum,
         maximum=maximum,
-        initial_value=config_proxy.get_value(config_key),
+        initial_value=getattr(config_proxy, config_key),
         status_tip=status_tip,
         on_change=None,
         show_ticks=True,
@@ -362,16 +444,20 @@ def widget_row_from_field(
         for key, val in asdict(metadata).items()
         if key not in ("label", "description") and val is not None
     }
+
     # Special cases:
+    #  * The setting is a small numerical range:
     if (
         metadata.minimum is not None
         and metadata.maximum is not None
         and abs(metadata.minimum - metadata.maximum) < 25
     ):
         widget_factory = widget_int_range
+    #  * The setting is a path to a directory/file:
     if metadata.file_type is not None:
         widget_factory = widget_path
         widget_args = {**widget_args, **{"parent": parent}}
+
     widget_row = widget_factory(
         config_proxy,
         config_key=field.name,
