@@ -9,8 +9,6 @@ from .component import (
     GuiProgress,
     get_text_input,
     MandatoryLabel,
-    create_verify_dtr_checkbox,
-    create_verify_filename_checkbox,
     ToolBar,
     LineEdit,
     grid_layout,
@@ -18,9 +16,9 @@ from .component import (
     hbox_layout,
 )
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
-from .theme import Action
 from .model import new_sftp_connection, AppData
 from .pyside import QtCore, QtGui, QtWidgets, QAction, open_window
+from .theme import Action, IconRepainterWidget
 from .ui_model_bind import (
     bind,
     TextControl,
@@ -37,56 +35,42 @@ from ..utils.config import ConnectionStore
 from ..workflows import transfer
 
 
-class TransferTab(BaseTab):
-    """Class that creates the "Transfer" Tab of the GUI application."""
+class TransferProtocol(enum.Enum):
+    sftp = "SFTP"
+    s3 = "S3-compatible"
+    liquid_files = "Liquid Files"
 
-    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
-        super().__init__(parent=parent)
-        self.app_data = app_data
-        self.connections_model = QtCore.QStringListModel()
-        files_panel = self.create_files_panel()
-        verify_dtr_group = QtWidgets.QGroupBox()
-        vbox_layout(
-            create_verify_dtr_checkbox(self.app_data, "transfer_verify_dtr"),
-            create_verify_filename_checkbox(
-                self.app_data, "transfer_verify_package_name"
-            ),
-            parent=verify_dtr_group,
-        )
+    @property
+    def status_tip(self) -> str:
+        return {
+            TransferProtocol.sftp: "Secure (SSH) File Transfer Protocol.",
+            TransferProtocol.s3: "Amazon S3 (Simple Storage Service) compatible object storage.",
+            TransferProtocol.liquid_files: "A proprietary file-sharing service.",
+        }[self]
 
-        options_panel = self.create_options_panel()
-        self.create_run_panel("Transfer data", self.transfer, "Transfer selected files")
-        self.app_data.add_listener("transfer_files", self._enable_buttons)
-        self.create_console()
-        self.create_progress_bar()
+    def create_button(self) -> QtWidgets.QRadioButton:
+        btn = QtWidgets.QRadioButton(self.value)
+        btn.setStatusTip(self.status_tip)
+        return btn
 
-        vbox_layout(
-            files_panel,
-            verify_dtr_group,
-            options_panel,
-            self.run_panel,
-            self.console,
-            self.progress_bar,
-            parent=self,
-        )
+    def create_options_panel(
+        self, data: AppData, parent: IconRepainterWidget
+    ) -> QtWidgets.QGroupBox:
+        if self is TransferProtocol.sftp:
+            return self._create_sftp_options_panel(data, parent)
+        if self is TransferProtocol.s3:
+            return self._create_s3_options_panel(data)
+        if self is TransferProtocol.liquid_files:
+            return self._create_lf_options_panel(data)
+        raise RuntimeError("Unreachable")
 
-    def _enable_buttons(self) -> None:
-        self.set_buttons_enabled(len(self.app_data.transfer_files) > 0)
-
-    def create_files_panel(self) -> QtWidgets.QGroupBox:
-        box = ArchiveOnlyFileSelectionWidget(
-            title="Encrypted files to transfer", parent=self
-        )
-        box.file_list_model.layoutChanged.connect(  # type: ignore
-            lambda: setattr(self.app_data, "transfer_files", box.get_list())
-        )
-        return box
-
-    def create_sftp_options_panel(self) -> QtWidgets.QGroupBox:
-        sftp_args = self.app_data.transfer_protocol_args[Sftp]
+    def _create_sftp_options_panel(
+        self, data: AppData, parent: IconRepainterWidget
+    ) -> QtWidgets.QGroupBox:
+        args = data.transfer_protocol_args[Sftp]
         text_username = LineEdit()
         text_username.setStatusTip("Username on the SFTP server")
-        bind(sftp_args, "username", text_username, TextControl)
+        bind(args, "username", text_username, TextControl)
 
         text_destination_dir = LineEdit()
         text_destination_dir.setStatusTip(
@@ -94,26 +78,26 @@ class TransferTab(BaseTab):
             "destination directory on the SFTP "
             "server"
         )
-        bind(sftp_args, "destination_dir", text_destination_dir, TextControl)
+        bind(args, "destination_dir", text_destination_dir, TextControl)
 
         text_host = LineEdit()
         text_host.setStatusTip("URL of the SFTP server with an optional port number")
-        bind(sftp_args, "host", text_host, TextControl)
+        bind(args, "host", text_host, TextControl)
 
         text_jumphost = LineEdit()
         text_jumphost.setStatusTip("(optional) URL of the jumphost server")
-        bind(sftp_args, "jumphost", text_jumphost, OptionalTextControl)
+        bind(args, "jumphost", text_jumphost, OptionalTextControl)
 
-        pkey_location = PathInput(directory=False, path=None, parent=self)
+        pkey_location = PathInput(directory=False, path=None, parent=parent)
         pkey_location.setStatusTip(
             "Path to the private SSH key used for authentication"
         )
-        bind(sftp_args, "pkey", pkey_location, OptionalPathControl)
+        bind(args, "pkey", pkey_location, OptionalPathControl)
 
         pkey_password = LineEdit()
         pkey_password.setStatusTip("Passphrase for the SSH private key")
-        pkey_password.setEchoMode(QtWidgets.QLineEdit.Password)
-        bind(sftp_args, "pkey_password", pkey_password, OptionalPasswordControl)
+        pkey_password.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
+        bind(args, "pkey_password", pkey_password, OptionalPasswordControl)
 
         box = QtWidgets.QGroupBox()
         box.setFlat(True)
@@ -133,14 +117,41 @@ class TransferTab(BaseTab):
         )
         return box
 
-    def create_liquidfiles_options_panel(self) -> QtWidgets.QGroupBox:
-        lf_args = self.app_data.transfer_protocol_args[LiquidFiles]
+    def _create_s3_options_panel(self, data: AppData) -> QtWidgets.QGroupBox:
+        args = data.transfer_protocol_args[S3]
 
         text_host = LineEdit()
-        bind(lf_args, "host", text_host, TextControl)
+        bind(args, "host", text_host, TextControl)
+
+        text_bucket = LineEdit()
+        bind(args, "bucket", text_bucket, TextControl)
+
+        text_access_key = LineEdit()
+        bind(args, "access_key", text_access_key, TextControl)
+
+        text_secret_key = LineEdit()
+        text_secret_key.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
+        bind(args, "secret_key", text_secret_key, OptionalPasswordControl)
+
+        box = QtWidgets.QGroupBox()
+        box.setFlat(True)
+        grid_layout(
+            (MandatoryLabel("Host URL"), text_host),
+            (MandatoryLabel("Bucket"), text_bucket),
+            (MandatoryLabel("Access Key"), text_access_key),
+            (MandatoryLabel("Secret Key"), text_secret_key),
+            parent=box,
+        )
+        return box
+
+    def _create_lf_options_panel(self, data: AppData) -> QtWidgets.QGroupBox:
+        args = data.transfer_protocol_args[LiquidFiles]
+
+        text_host = LineEdit()
+        bind(args, "host", text_host, TextControl)
 
         text_api_key = LineEdit()
-        bind(lf_args, "api_key", text_api_key, TextControl)
+        bind(args, "api_key", text_api_key, TextControl)
 
         box = QtWidgets.QGroupBox()
         box.setFlat(True)
@@ -151,30 +162,38 @@ class TransferTab(BaseTab):
         )
         return box
 
-    def create_s3_options_panel(self) -> QtWidgets.QGroupBox:
-        s3_args = self.app_data.transfer_protocol_args[S3]
 
-        text_host = LineEdit()
-        bind(s3_args, "host", text_host, TextControl)
+class TransferTab(BaseTab):
+    """Class that creates the "Transfer" Tab of the GUI application."""
 
-        text_bucket = LineEdit()
-        bind(s3_args, "bucket", text_bucket, TextControl)
+    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
+        super().__init__(parent=parent)
+        self.app_data = app_data
+        self.connections_model = QtCore.QStringListModel()
+        files_panel = self.create_files_panel()
+        options_panel = self.create_options_panel()
+        self.create_run_panel("Transfer data", self.transfer, "Transfer selected files")
+        self.create_console()
+        self.create_progress_bar()
+        vbox_layout(
+            files_panel,
+            options_panel,
+            self.run_panel,
+            self.console,
+            self.progress_bar,
+            parent=self,
+        )
 
-        text_access_key = LineEdit()
-        bind(s3_args, "access_key", text_access_key, TextControl)
-
-        text_secret_key = LineEdit()
-        text_secret_key.setEchoMode(QtWidgets.QLineEdit.Password)
-        bind(s3_args, "secret_key", text_secret_key, OptionalPasswordControl)
-
-        box = QtWidgets.QGroupBox()
-        box.setFlat(True)
-        grid_layout(
-            (MandatoryLabel("Host URL"), text_host),
-            (MandatoryLabel("Bucket"), text_bucket),
-            (MandatoryLabel("Access Key"), text_access_key),
-            (MandatoryLabel("Secret Key"), text_secret_key),
-            parent=box,
+    def create_files_panel(self) -> QtWidgets.QGroupBox:
+        box = ArchiveOnlyFileSelectionWidget(
+            title="Encrypted files to transfer",
+            parent=self,
+            model=self.app_data.transfer_files,
+        )
+        self.app_data.transfer_files.layoutChanged.connect(  # type: ignore
+            lambda: self.set_buttons_enabled(
+                self.app_data.transfer_files.rowCount() > 0
+            )
         )
         return box
 
@@ -188,10 +207,11 @@ class TransferTab(BaseTab):
             dialog.setWindowTitle("Connection profile")
             dialog.setText(text)
             dialog.setStandardButtons(
-                QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
+                QtWidgets.QMessageBox.StandardButton.Ok
+                | QtWidgets.QMessageBox.StandardButton.Cancel
             )
-            dialog.setDefaultButton(QtWidgets.QMessageBox.Cancel)
-            return bool(open_window(dialog) == QtWidgets.QMessageBox.Ok)
+            dialog.setDefaultButton(QtWidgets.QMessageBox.StandardButton.Cancel)
+            return bool(open_window(dialog) == QtWidgets.QMessageBox.StandardButton.Ok)
 
         def rename() -> None:
             label_old = connections_selection.currentText()
@@ -282,19 +302,22 @@ class TransferTab(BaseTab):
         connections_selection.setModel(self.connections_model)
         self.connections_model.setStringList(list(self.app_data.config.connections))
 
+        protocol_sftp = TransferProtocol.sftp
+        protocol_s3 = TransferProtocol.s3
+        protocol_lf = TransferProtocol.liquid_files
+
         protocol_btn_grp = QtWidgets.QButtonGroup(box)
-        protocol_btn_grp.addButton(QtWidgets.QRadioButton("sftp"))
-        protocol_btn_grp.addButton(QtWidgets.QRadioButton("s3"))
-        protocol_btn_grp.addButton(QtWidgets.QRadioButton("liquid_files"))
-        get_btn_from_group(protocol_btn_grp, "sftp").setChecked(True)
+        for p in (protocol_sftp, protocol_s3, protocol_lf):
+            protocol_btn_grp.addButton(p.create_button())
+
+        get_btn_from_group(protocol_btn_grp, protocol_sftp.value).setChecked(True)
 
         protocol_boxes = {
-            "sftp": self.create_sftp_options_panel(),
-            "s3": self.create_s3_options_panel(),
-            "liquid_files": self.create_liquidfiles_options_panel(),
+            p.name: p.create_options_panel(self.app_data, self)
+            for p in (protocol_sftp, protocol_s3, protocol_lf)
         }
-        protocol_boxes["s3"].hide()
-        protocol_boxes["liquid_files"].hide()
+        for p in (protocol_s3, protocol_lf):
+            protocol_boxes[p.name].hide()
 
         def load_connection() -> None:
             connection = self.app_data.config.connections.get(
@@ -303,7 +326,9 @@ class TransferTab(BaseTab):
             if not connection:
                 return
             protocol = protocols.protocol_name[type(connection)]
-            get_btn_from_group(protocol_btn_grp, protocol).click()
+            get_btn_from_group(
+                protocol_btn_grp, TransferProtocol[protocol].value
+            ).click()
             self.app_data.transfer_protocol_args[
                 self.app_data.transfer_protocol_type
             ].target = connection
@@ -311,11 +336,12 @@ class TransferTab(BaseTab):
         connections_selection.currentTextChanged.connect(load_connection)  # type: ignore
 
         def toggle_protocol(btn: QtWidgets.QRadioButton, state: bool) -> None:
+            protocol_name = TransferProtocol(btn.text()).name
             if state:
                 self.app_data.transfer_protocol_type = protocols.parse_protocol(
-                    btn.text()
+                    protocol_name
                 )
-            protocol_boxes[btn.text()].setVisible(state)
+            protocol_boxes[protocol_name].setVisible(state)
 
         protocol_btn_grp.buttonToggled.connect(toggle_protocol)  # type: ignore
 
@@ -369,12 +395,10 @@ class TransferTab(BaseTab):
         self.run_workflow_thread(
             transfer.transfer,
             f_kwargs=dict(
-                files=self.app_data.transfer_files,
+                files=self.app_data.transfer_files.stringList(),
                 protocol=protocol,
                 config=self.app_data.config,
                 dry_run=dry_run,
-                verify_dtr=self.app_data.transfer_verify_dtr,
-                verify_pkg_name=self.app_data.transfer_verify_package_name,
                 pkg_name_suffix=self.app_data.encrypt_package_name_suffix,
                 progress=GuiProgress(self.progress_bar.setValue),
                 two_factor_callback=second_factor_callback,
@@ -399,10 +423,13 @@ class ConnectionDialog(QtWidgets.QDialog):
     ):
         super().__init__(parent=parent)
         self.setWindowTitle("Connection profile")
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(
+            self.windowFlags() & ~QtCore.Qt.WindowType.WindowContextHelpButtonHint
+        )
 
         btn_box = QtWidgets.QDialogButtonBox(
-            QtWidgets.QDialogButtonBox.Ok | QtWidgets.QDialogButtonBox.Cancel
+            QtWidgets.QDialogButtonBox.StandardButton.Ok
+            | QtWidgets.QDialogButtonBox.StandardButton.Cancel
         )
         btn_box.accepted.connect(self.accept)  # type: ignore
         btn_box.rejected.connect(self.reject)  # type: ignore
@@ -414,7 +441,7 @@ class ConnectionDialog(QtWidgets.QDialog):
         self.text_field.setText(default_input)
 
         def set_ok_enabled(text: str) -> None:
-            btn_box.button(QtWidgets.QDialogButtonBox.Ok).setEnabled(
+            btn_box.button(QtWidgets.QDialogButtonBox.StandardButton.Ok).setEnabled(
                 len(text) > 0 and text not in forbidden
             )
 
