@@ -1,3 +1,4 @@
+import abc
 from typing import Callable, Optional, Any, Type, TypeVar, Generic, cast, Union
 from pathlib import Path
 
@@ -18,13 +19,15 @@ class Control(Generic[T, T_WIDGET]):
     """
 
     @classmethod
+    @abc.abstractmethod
     def signal_connect(cls, widget: Any) -> Callable[[Callable[[T], None]], None]:
         # NOTE: widget is typed as "Any" for lack of a better solution.
-        pass
+        raise NotImplementedError
 
     @classmethod
+    @abc.abstractmethod
     def setter(cls, widget: T_WIDGET) -> Callable[[T], None]:
-        pass
+        raise NotImplementedError
 
 
 class SignalControl(Control[T, T_WIDGET]):
@@ -33,12 +36,14 @@ class SignalControl(Control[T, T_WIDGET]):
     """
 
     @classmethod
+    @abc.abstractmethod
     def signal(cls, widget: T_WIDGET) -> Callable[[T], None]:
-        pass
+        raise NotImplementedError
 
     @classmethod
+    @abc.abstractmethod
     def getter(cls, widget: T_WIDGET) -> Callable[[], Any]:
-        pass
+        raise NotImplementedError
 
     @classmethod
     def signal_connect(cls, widget: T_WIDGET) -> Callable[[Callable[[T], None]], None]:
@@ -61,7 +66,9 @@ class BoolControl(Control[bool, QtWidgets.QCheckBox]):
         def _connect(callback: Callable[[bool], None]) -> None:
             widget.stateChanged.connect(
                 callback_with_conversion(
-                    callback, lambda state: state == QtCore.Qt.Checked
+                    callback,
+                    lambda state: QtCore.Qt.CheckState(state)
+                    == QtCore.Qt.CheckState.Checked,
                 )
             )
 
@@ -108,7 +115,7 @@ class TextControl(SignalControl[str, QtWidgets.QLineEdit], Generic[T_STR_OR_SECR
 
     @classmethod
     def signal(cls, widget: QtWidgets.QLineEdit) -> Callable[[str], None]:
-        text_changed_method: Callable[[str], None] = widget.textChanged  # type: ignore
+        text_changed_method: Callable[[str], None] = widget.editingFinished  # type: ignore
         return text_changed_method
 
     @classmethod
@@ -191,7 +198,7 @@ def bind(
     widget_type: Type[Any],
 ) -> None:
     widget_type.signal_connect(widget)(lambda val: state.set_value(attr, val))
-    state.add_listener(attr, lambda: widget_type.setter(widget)(state.get_value(attr)))
+    state.add_listener(attr, lambda: widget_type.setter(widget)(getattr(state, attr)))
 
 
 def to_signal_callback(
