@@ -1,12 +1,16 @@
 from typing import Type, Dict, Tuple
 
 from .protocol import Protocol as _Protocol
-from . import liquid_files, sftp
+from . import liquid_files, sftp, s3
 
 # reexport
 Protocol = _Protocol
 
-protocols: Tuple[Type[Protocol], ...] = (sftp.Protocol, liquid_files.Protocol)
+protocols: Tuple[Type[Protocol], ...] = (
+    sftp.Protocol,
+    liquid_files.Protocol,
+    s3.Protocol,
+)
 protocols_by_name: Dict[str, Type[Protocol]] = {
     p.__module__.replace(__name__ + ".", ""): p for p in protocols
 }
