@@ -78,6 +78,7 @@ class Protocol(protocol.Protocol):
         "utf_8"  # nosec (False Positive: pkey_password_encoding)
     )
     jumphost: Optional[str] = None
+    buffer_size: int = 1048576
 
     def __post_init__(self) -> None:
         # Turn empty strings into None and check that the ssh key file exists
@@ -115,6 +116,7 @@ class Protocol(protocol.Protocol):
                     reveal(self.pkey_password),
                     progress.update if progress is not None else None,
                     two_factor_callback=two_factor_callback,
+                    buf_size=self.buffer_size,
                 )
             except RuntimeError as e:
                 logger.warning(format(e))
