@@ -3,11 +3,20 @@ import json
 import os
 import platform
 import warnings
+import dataclasses
 from dataclasses import dataclass, field as _field, fields
 from pathlib import Path
 from typing import Dict, Optional, Callable, Union, Any
 
+# TODO: this can be removed when support for python 3.7 is dropped, as
+#       typing.get_args is natively present in python >= 3.8.
+try:
+    from typing import get_args
+except ImportError:
+    from typing_extensions import get_args
+
 from libbiomedit.lib import deserialize as serialization
+from libbiomedit.portal import PortalApi
 
 from .log import get_default_log_dir, create_logger
 from .validation import REGEX_FQDN, PACKAGE_SUFFIX
@@ -16,7 +25,6 @@ from .. import APP_NAME_SHORT
 from ..core import gpg
 from ..core.error import UserError
 from ..core.filesystem import reverse_expanduser, abspath_expanduser
-from ..core.portal_api import PortalApi
 from ..protocols import Protocol, protocol_name, parse_protocol
 
 PKEY_PARAM_NAME = "pkey"
@@ -115,13 +123,13 @@ class Config:
 
     dcc_portal_url: str = field_ext(
         default="https://portal.dcc.sib.swiss",
-        label="DCC portal URL",
-        description="URL of portal instance. The portal is used for key signing and "
-        "DTR (Data Transfer Request) validation.",
+        label="Portal URL",
+        description="URL of portal instance. The portal is used for key "
+        "signing and DTR (Data Transfer Request) validation.",
         regex=REGEX_FQDN,
     )
     keyserver_url: Optional[str] = field_ext(
-        default="https://keyserver.dcc.sib.swiss",
+        default="https://keys.openpgp.org",
         label="Keyserver URL",
         description="URL of the keyserver: used for publishing/fetching public PGP keys.",
         regex=REGEX_FQDN,
@@ -135,13 +143,6 @@ class Config:
         "configuration files.",
         file_type=FileType.directory,
     )
-    key_authority_fingerprint: Optional[str] = field_ext(
-        default="B37CE2A101EBFA70941DF885881685B5EE0FCBD3",
-        label="Key validation authority fingerprint",
-        description="Fingerprint (40 characters) of the key validation authority's "
-        "PGP key. If a value is specified, only keys signed the "
-        "authority's key can be used.",
-    )
     sign_encrypted_data: bool = field_ext(
         default=True,
         label="Sign encrypted data",
@@ -154,7 +155,7 @@ class Config:
     )
     repo_url: str = field_ext(
         default="https://pypi.org",
-        label="Repo URL",
+        label="Repository URL",
         description="Python package repository, used when looking for updates.",
         regex=REGEX_FQDN,
     )
@@ -163,12 +164,6 @@ class Config:
         label="Check version",
         description="Check whether you have the latest version of sett on startup.",
     )
-    offline: bool = field_ext(
-        default=False,
-        label="Offline mode",
-        description="In offline mode, sett will not make any network connections: "
-        "DTR verification and automatic PGP key downloading/updating is disabled.",
-    )
     log_dir: str = field_ext(
         serialize=reverse_expanduser_if_path_exists,
         deserialize=abspath_expanduser,
@@ -248,7 +243,6 @@ class Config:
         description="Allow the automatic download and refresh of PGP keys "
         "from the Keyserver.",
     )
-
     verify_package_name: bool = field_ext(
         default=True,
         label="Verify package name",
@@ -256,13 +250,25 @@ class Config:
         f"{APP_NAME_SHORT} naming convention",
     )
     sftp_buffer_size: int = field_ext(
-        default=1_048_576,
-        minimum=65_536,
-        maximum=16_777_216,
+        default=1 << 20,  # 1 MB
+        minimum=1 << 16,  # 64 kB
+        maximum=1 << 24,  # 16 MB
         label="SFTP buffer size",
         description="SFTP buffer size in bytes. Larger values usually result in "
         "faster transfer speed on stable networks.",
     )
+    verify_key_approval: bool = field_ext(
+        default=True,
+        label="Verify key approval",
+        description="Verify that the PGP keys are approved by the "
+        "central authority.",
+    )
+    verify_dtr: bool = field_ext(
+        default=True,
+        label="Verify DTR",
+        description="Verify that the given Data Transfer ID is valid and the "
+        "associated metadata is correct.",
+    )
 
     def __post_init__(self) -> None:
         for url in ("dcc_portal_url", "repo_url"):
@@ -283,19 +289,57 @@ class Config:
         """Property indicating whether GPG keys can be automatically downloaded
         and refreshed from a keyserver, if a keyserver is specified.
         Key auto-download is not allowed in the following situations:
-         * There is no defined validation authority. If keys do not need to be
-           certified by a central key authority, auto-downloading them presents
+         * The user has decided to not allow it.
+         * There is no key approval verification. If keys do not need to be
+           approved by a central key authority, auto-downloading them presents
            a security risk (keys should be manually downloaded and checked) and
            is therefore not allowed.
-         * The 'offline' mode is activated, no network access is allowed.
-         * The user has decided to not allow it.
         """
-        return (
-            self.key_authority_fingerprint is not None
-            and not self.offline
-            and self.gpg_key_autodownload
+        return self.gpg_key_autodownload and self.verify_key_approval
+
+    # TODO: when dropping support for python 3.7, remove quotes around "Field"
+    #       and dataclasses.Field will no longer need to be imported.
+    @classmethod
+    def get_field(cls, arg: str) -> "dataclasses.Field[Any]":
+        """Return the class field corresponding to the argument `arg`.
+
+        :raise ValueError: if the specified `arg` is not an argument of the
+            class.
+        """
+        for f in fields(cls):
+            if f.name == arg:
+                return f
+
+        raise ValueError(f"{APP_NAME_SHORT} Config has no attribute '{arg}'.")
+
+    @classmethod
+    def is_mandatory_argument(cls, arg: str) -> bool:
+        """Return `True` if the specified argument `arg` is mandatory in the
+        application's configuration. Return `False` if argument is optional.
+
+        :param arg: name of config argument to check for being mandatory.
+        """
+        return type(None) not in get_args(cls.get_field(arg).type)
+
+    @classmethod
+    def get_default_value(cls, arg: str) -> Any:
+        """Return default value of the application's configuration argument
+        `arg`.
+
+        :raise ValueError: if the specified `arg` has no default value.
+        """
+        f = cls.get_field(arg)
+        if f.default is not dataclasses.MISSING:
+            return f.default
+
+        raise ValueError(
+            f"{APP_NAME_SHORT} Config attribute '{arg}' has no default value."
         )
 
+    @classmethod
+    def get_label(cls, arg: str) -> str:
+        return str(cls.get_field(arg).metadata["metadata"].label)
+
 
 class ConnectionStore:
     """Sftp/LiquidFiles connection configuration storage manager."""
@@ -350,7 +394,6 @@ class ConnectionStore:
 def load_config() -> Config:
     """Loads the config, returning a Config object."""
 
-    # TODO: remove migration (see issue 283)
     migrate_user_config_file()
 
     cfg_dct = {}
@@ -433,8 +476,7 @@ def open_gpg_dir(gpg_dir: str) -> gpg.GPGStore:
     :return: a gpg-lite GPGStore
     :raises UserError:
     """
-    if not Path(gpg_dir).is_dir():
-        os.makedirs(gpg_dir, mode=0o700)
+    os.makedirs(gpg_dir, mode=0o700, exist_ok=True)
 
     try:
         return gpg.GPGStore(gnupg_home_dir=gpg_dir)
@@ -454,12 +496,25 @@ def migrate_user_config_file() -> None:
     except UserError:
         return
 
-    # Migration to remove "temp_dir" from config.
-    # Migration added in July 2021, can be removed after about a year.
-    if "temp_dir" in config_dict:
-        del config_dict["temp_dir"]
+    # Migration to remove `offline` from config.
+    # Migration added in October 2022, can be removed after about a year.
+    if "offline" in config_dict:
+        del config_dict["offline"]
         config_needs_update = True
 
+    # Migration to remove `key_authority_fingerprint` from config.
+    # Migration added in August 2022, can be removed after about a year.
+    if "key_authority_fingerprint" in config_dict:
+        del config_dict["key_authority_fingerprint"]
+        config_needs_update = True
+
+    # Migration to update keyserver URL from config.
+    # Migration added in August 2022, can be removed after about a year.
+    if "keyserver_url" in config_dict:
+        if "keyserver.dcc.sib.swiss" in config_dict["keyserver_url"]:
+            config_dict["keyserver_url"] = Config().keyserver_url
+            config_needs_update = True
+
     if "connections" in config_dict:
         for connection in config_dict["connections"].values():
             if "pkey_password" in connection["parameters"]:
