@@ -1,5 +1,4 @@
 import os
-
 from functools import partial
 from typing import List, Optional
 
@@ -18,7 +17,6 @@ from ..core.crypt import (
     decrypt as core_decrypt,
     enforce_passphrase,
     retrieve_refresh_and_validate_keys,
-    fingerprint2keyid,
     verify_metadata_signature,
 )
 from ..core.filesystem import (
@@ -31,11 +29,11 @@ from ..core.filesystem import (
 )
 from ..core.checksum import verify_checksums, read_checksum_file
 from ..core.secret import Secret
+from ..core.error import UserError
 from ..utils.log import create_logger, log_runtime_info, log_timing
 from ..utils.progress import ProgressInterface, subprogress
 from ..utils.config import Config
 
-
 logger = create_logger(__name__)
 
 
@@ -105,36 +103,39 @@ def decrypt_archive(
     out_dir = unique_filename(
         os.path.splitext(os.path.join(output_dir, os.path.basename(archive_file)))[0]
     )
-
     with DeleteDirOnError(out_dir):
+        # Verify that the detached signature on the metadata.json file is
+        # valid, and that the fingerprint matches the sender fingerprint
+        # from the metadata file.
+        # Note: this does **not** verify that the data sender's key is
+        # approved by the key approval authority, but that doesn't matter
+        # because it gets checked later in the function.
         logger.info("Verifying signatures")
         verify_metadata_signature(
             tar_file=archive_file,
             gpg_store=config.gpg_store,
-            signee_fingerprint=None,
-            key_authority_fingerprint=config.key_authority_fingerprint,
             keyserver_url=config.keyserver_url,
-            validate_key_origin=False,
+            allow_key_download=config.allow_gpg_key_autodownload,
         )
 
-        logger.info("Verifying encryption keys")
+        # Find the secret key(s) for which the data was encrypted in the
+        # user's local keyring.
+        logger.info("Verifying decryption keys")
         with extract(archive_file, DATA_FILE_ENCRYPTED) as f_data:
-            keys = list(
-                retrieve_refresh_and_validate_keys(
-                    key_search_terms=gpg.extract_key_id(f_data),
-                    gpg_store=config.gpg_store,
-                    key_authority_fingerprint=config.key_authority_fingerprint,
-                    keyserver_url=config.keyserver_url,
-                    allow_key_download=config.allow_gpg_key_autodownload,
+            secret_keys = config.gpg_store.list_sec_keys(gpg.extract_key_id(f_data))
+            if not secret_keys:
+                raise UserError(
+                    "No secret key able to decrypt the data was found. "
+                    "Please make sure your secret key is present on the local "
+                    "machine and that the data was encrypted for you."
                 )
-            )
             logger.info(
                 "Data encrypted for: %s",
-                ", ".join(f"{key.uids[0]} ({key.fingerprint})" for key in keys),
+                ", ".join(f"{key.uids[0]} ({key.fingerprint})" for key in secret_keys),
             )
             check_password_matches_any_key(
                 password=enforce_passphrase(passphrase),
-                keys=keys,
+                keys=secret_keys,
                 gpg_store=config.gpg_store,
             )
 
@@ -147,7 +148,7 @@ def decrypt_archive(
             archive_file, scaled_progress, DATA_FILE_ENCRYPTED
         ) as f_data:
             os.makedirs(out_dir, exist_ok=True)
-            sender_fprs = core_decrypt(
+            sender_fingerprint = core_decrypt(
                 source=f_data,
                 output=os.path.join(out_dir, DATA_ARCHIVE)
                 if decrypt_only
@@ -155,18 +156,13 @@ def decrypt_archive(
                 gpg_store=config.gpg_store,
                 passphrase=passphrase,
             )
-            sender_sig_keys = retrieve_refresh_and_validate_keys(
-                key_search_terms=map(fingerprint2keyid, sender_fprs),
-                gpg_store=config.gpg_store,
-                key_authority_fingerprint=config.key_authority_fingerprint,
-                keyserver_url=config.keyserver_url,
-                allow_key_download=config.allow_gpg_key_autodownload,
+            sender_key = retrieve_refresh_and_validate_keys(
+                key_identifiers=sender_fingerprint,
+                config=config,
             )
             logger.info(
                 "Data signed by: %s",
-                ", ".join(
-                    f"{key.uids[0]} ({key.fingerprint})" for key in sender_sig_keys
-                ),
+                ", ".join(f"{key.uids[0]} ({key.fingerprint})" for key in sender_key),
             )
 
         # Compute decrypted data size and checksum verification (if data was
@@ -178,13 +174,13 @@ def decrypt_archive(
                 )
             else:
                 logger.info("Checksum verification of uncompressed data")
-                with open(os.path.join(out_dir, CHECKSUM_FILE), "rb") as fout:
+                with open(os.path.join(out_dir, CHECKSUM_FILE), "rb") as f:
                     # Path separator replacement is a fail-safe if paths are
                     # not POSIX.
                     verify_checksums(
                         [
                             (c, os.path.join(out_dir, p.replace("\\", os.path.sep)))
-                            for c, p in read_checksum_file(fout)
+                            for c, p in read_checksum_file(f)
                         ],
                         # `max_workers` accepts only None and positive integers.
                         max_workers=config.max_cpu if config.max_cpu > 0 else None,
