@@ -8,13 +8,12 @@ from typing import List, Optional, Callable, Tuple, Iterable, Any, TypeVar
 from zipfile import ZipFile, ZipInfo, ZIP_STORED
 
 from ..core import gpg
+from ..core.metadata import METADATA_FILE, METADATA_FILE_SIG
 from ..core.archive import (
     write_tar,
     ArchiveInMemoryFile,
     ArchiveFile,
     ArchiveFileBase,
-    METADATA_FILE,
-    METADATA_FILE_SIG,
     DATA_FILE_ENCRYPTED,
     CHECKSUM_FILE,
     CONTENT_FOLDER,
@@ -34,6 +33,7 @@ from ..core.crypt import (
     detach_sign_file,
     check_password,
     search_priv_key,
+    to_user_error,
 )
 from ..core.checksum import generate_checksums_file_content, compute_checksum_on_write
 from ..core.error import UserError
@@ -120,7 +120,6 @@ def encrypt(  # pylint: disable=too-many-statements
     output: Optional[str] = None,
     output_suffix: Optional[str] = None,
     dry_run: bool = False,
-    verify_dtr: bool = True,
     force: bool = False,
     compression_level: Optional[int] = None,
     purpose: Optional[Purpose] = None,
@@ -169,24 +168,17 @@ def encrypt(  # pylint: disable=too-many-statements
             arg_type_checker=check_compression_level,
         )
 
-        # Retrieve the sender's public and private keys, as well as the
-        # recipient's public key:
-        #  - sender private key: needed to sign the encrypted data.
-        #  - sender public key : will be checked to make sure it is signed by
-        #       the DCC. Only private keys with a matching public key that is
-        #       signed by the DCC will be allowed to be used.
+        # Retrieve the sender's and recipients' public keys:
+        #  - sender public key : the matching private key will be used to
+        #                        encrypt data.
         #  - recipient public key: needed to encrypt the data.
         #
         # The sender/recipient information can be either an email, a keyID or
         # a full fingerprint.
         logger.info("Retrieve sender and recipient GnuPG keys")
         sender_pub_key, *recipients_pub_key = retrieve_refresh_and_validate_keys(
-            key_search_terms=(sender, *recipient),
-            gpg_store=config.gpg_store,
-            key_authority_fingerprint=config.key_authority_fingerprint,
-            keyserver_url=config.keyserver_url,
-            validate_key_origin=False,
-            allow_key_download=config.allow_gpg_key_autodownload,
+            key_identifiers=(sender, *recipient),
+            config=config,
         )
 
         # Verify a private key matching the user's public key exists. The key
@@ -205,7 +197,7 @@ def encrypt(  # pylint: disable=too-many-statements
         )
 
         # If requested, verify data transfer related information.
-        if verify_dtr:
+        if config.verify_dtr:
             logger.info("Verify Data Transfer ID")
             # Connect to the portal API to retrieve the code (abbreviation)
             # associated with the DTR ID.
@@ -294,7 +286,7 @@ def encrypt(  # pylint: disable=too-many-statements
                     ZipInfo(DATA_FILE_ENCRYPTED, date_time=timestamp.timetuple()[:6]),
                     mode="w",
                     force_zip64=True,
-                ) as fout:
+                ) as output_file:
                     encrypt_and_sign(
                         source=partial(
                             write_tar,
@@ -304,7 +296,7 @@ def encrypt(  # pylint: disable=too-many-statements
                         ),
                         output=partial(
                             compute_checksum_on_write,
-                            fout=fout,
+                            output_file=output_file,
                             checksum_buffer=encrypted_checksum_buf,
                         ),
                         gpg_store=config.gpg_store,
@@ -401,6 +393,7 @@ def byte_encode_metadata(
     return metadata_bytes, metadata_signature_bytes
 
 
+@to_user_error(RuntimeError)
 def verify_dtr_info_and_get_project_code(
     dtr_id: Optional[int],
     purpose: Optional[Purpose],
@@ -410,13 +403,15 @@ def verify_dtr_info_and_get_project_code(
 ) -> str:
     """Determine the "code" (i.e. short name) of a project based on its DTR ID
     (Data Transfer ID) and perform some sanity checks on data associated with
-    the tranfer by querying the portal API:
+    the transfer by querying the portal API:
      * Verify the data sender's key (sender_pub_key) is authorized.
      * Verify the data recipients' keys (recipients_pub_key) is authorized and
        that the recipient is a DM (data manager) for the project.
      * Verify that the purpose is correct.
 
     If all these checks complete successfully, the project "code" is returned.
+
+    :raises UserError: if any of the specified checks fail.
     """
 
     error_prefix = "Cannot verify DTR (Data Transfer Request) ID"
@@ -424,25 +419,22 @@ def verify_dtr_info_and_get_project_code(
         raise UserError(f"{error_prefix}: 'DTR ID' is missing.")
     if not purpose:
         raise UserError(f"{error_prefix}: 'purpose' is missing.")
-    if config.offline:
-        raise UserError(f"{error_prefix}: offline mode is on.")
     if not config.portal_api:
         raise UserError(f"{error_prefix}: no portal URL specified in config.")
 
-    try:
-        project_code = config.portal_api.verify_transfer(
-            metadata=MetaData(
-                transfer_id=dtr_id,
-                sender=HexStr1024(sender_pub_key.fingerprint),
-                recipients=[HexStr1024(key.fingerprint) for key in recipients_pub_key],
-                checksum=HexStr256("0" * 64),
-                purpose=purpose,
-            ),
-            filename="missing",
-        )
-    except RuntimeError as e:
-        raise UserError(format(e)) from e
-    return project_code
+    # Query the portal API for the specified DTR ID and return project code.
+    # Raises a RuntimeError if the DTR is not-approved or some of the metadata
+    # does not match with the project the DTR ID belongs to.
+    return config.portal_api.verify_dpkg_metadata(
+        metadata=MetaData(
+            transfer_id=dtr_id,
+            sender=HexStr1024(sender_pub_key.fingerprint),
+            recipients=[HexStr1024(key.fingerprint) for key in recipients_pub_key],
+            checksum=HexStr256("0" * 64),
+            purpose=purpose,
+        ),
+        file_name="missing",
+    )
 
 
 def generate_output_archive_name(
