@@ -9,10 +9,9 @@ from ..core.crypt import get_recipient_email, retrieve_refresh_and_validate_keys
 from ..core.archive import (
     check_package,
     extract_multiple,
-    METADATA_FILE,
     DATA_FILE_ENCRYPTED,
 )
-from ..core.metadata import load_metadata
+from ..core.metadata import load_metadata, METADATA_FILE
 from ..core.error import UserError
 from ..utils.config import Config
 from ..utils.log import create_logger, log_runtime_info, log_timing
@@ -33,8 +32,6 @@ def transfer(
     config: Config,
     two_factor_callback: Callable[[], str],
     dry_run: bool = False,
-    verify_dtr: Optional[bool] = None,
-    verify_pkg_name: bool = True,
     pkg_name_suffix: Optional[str] = None,
     progress: Optional[ProgressInterface] = None,
 ) -> None:
@@ -49,15 +46,6 @@ def transfer(
         it.
     :param dry_run: if True, tests on the data to be transferred are carried-out,
         but the actual transfer of files is skipped.
-    :param verify_dtr: if True, the Data Transfer ID indicated in the data
-        package's metadata is checked to ensure the transfer is authorized.
-        This feature requires that a central "data portal" is available (see
-        config file).
-        If verify_dtr is set to 'None', DTR ID verification is conditional upon
-        the presence of a DTR ID in the metadata of the file(s) to transfer.
-    :param verify_pkg_name: if True, a check on the name of the file(s) to be
-        transferred to verify that it matches an expected pattern:
-        <project_code>_<date_format>_<package_name_suffix>.zip
     :param pkg_name_suffix: by default, the <package_name_suffix> value used
         to check the file name (if the check is enabled) is taken from the
         user's config file. This optional argument allows to override this.
@@ -88,46 +76,40 @@ def transfer(
                 encrypted_file,
             ):
                 raw_metadata = json.load(metadata_io)
-                keys = tuple(
-                    retrieve_refresh_and_validate_keys(
-                        key_search_terms=gpg.extract_key_id(encrypted_file),
-                        gpg_store=config.gpg_store,
-                        key_authority_fingerprint=config.key_authority_fingerprint,
-                        keyserver_url=config.keyserver_url,
-                        allow_key_download=config.allow_gpg_key_autodownload,
-                    )
+                keys = retrieve_refresh_and_validate_keys(
+                    key_identifiers=gpg.extract_key_id(encrypted_file),
+                    config=config,
                 )
             metadata = load_metadata(raw_metadata)
 
-            # If DTR ID verification is not specifically enabled/disabled, then
-            # it is carried-out only if the metadata of the file to transfer
-            # contains a DTR ID value.
-            if verify_dtr is None:
-                verify_dtr = metadata.transfer_id is not None
-
-            if verify_dtr:
+            if config.verify_dtr:
                 if metadata.transfer_id is None:
                     raise UserError(
                         "DTR (Data Transfer Request) ID verification was "
                         "requested but DTR ID is missing in file metadata."
                     )
 
+                # Query the portal API for the specified DTR ID and return
+                # project code. Raises an RuntimeError if the DTR is
+                # not-approved or some of the metadata does not match with the
+                # project the DTR ID belongs to.
                 try:
-                    project_code = config.portal_api.verify_transfer(
-                        metadata=metadata, filename=archive_path
-                    )
-                    logger.info(
-                        "DTR ID '%s' is valid for project '%s'",
-                        metadata.transfer_id,
-                        project_code,
+                    project_code = config.portal_api.verify_dpkg_metadata(
+                        metadata=metadata, file_name=archive_path
                     )
                 except RuntimeError as e:
                     raise UserError(format(e)) from e
 
-            if verify_pkg_name:
+                logger.info(
+                    "DTR ID '%s' is valid for project '%s'",
+                    metadata.transfer_id,
+                    project_code,
+                )
+
+            if config.verify_package_name:
                 check_archive_name_follows_convention(
                     archive_path=archive_path,
-                    project_code=project_code if verify_dtr else None,
+                    project_code=project_code if config.verify_dtr else None,
                     package_name_suffix=pkg_name_suffix,
                 )
             files_by_recipient.setdefault(keys, []).append(archive_path)
@@ -194,9 +176,6 @@ def check_archive_name_follows_convention(
         "the naming convention. "
         "If the package name is prefixed with its project code, make sure "
         "that DTR ID verification is not disabled. "
-        "Alternatively, this file name verification can be temporarily "
-        "disabled by un-checking the 'Verify package name' checkbox in the "
-        "Transfer tab (GUI) or by passing the '--force' option (command line). "
         "To permanently disable this check, uncheck the 'Verify package name' "
         "checkbox in the Settings tab (GUI), or set 'verify_package_name' to "
         "'false' in the application's configuration file."
